#[repr(i32)]pub enum FlagStorageBackend {
Unspecified = 0,
None = 1,
Aconfigd = 2,
DeviceConfig = 3,
}Expand description
The underlying storage mechanism for the flag.
Variants
Implementations
Sourceimpl FlagStorageBackend
impl FlagStorageBackend
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.