#[repr(i32)]pub enum ValuePickedFrom {
Unspecified = 0,
Default = 1,
Server = 2,
Local = 3,
}Expand description
The source of the current flag value.
Variants
Unspecified = 0
Default = 1
The value is the build-time default.
Server = 2
The value comes from a server-side override.
Local = 3
The value comes from a local override on the device.
Implementations
Sourceimpl ValuePickedFrom
impl ValuePickedFrom
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.