GameModeInfo

pub struct GameModeInfo {
    pub mode: Option<u32>,
    pub use_angle: Option<bool>,
    pub resolution_downscale: Option<f32>,
    pub fps: Option<f32>,
}

Fields

mode: Option<u32>use_angle: Option<bool>resolution_downscale: Option<f32>fps: Option<f32>

Implementations

Source

impl GameModeInfo

pub fn mode(&self) -> u32

Returns the value of mode, or the default value if mode is unset.

pub fn use_angle(&self) -> bool

Returns the value of use_angle, or the default value if use_angle is unset.

pub fn resolution_downscale(&self) -> f32

Returns the value of resolution_downscale, or the default value if resolution_downscale is unset.

pub fn fps(&self) -> f32

Returns the value of fps, or the default value if fps is unset.