TimestampsInUs

Struct TimestampsInUs 

pub struct TimestampsInUs {
    pub interval_delta: Option<i64>,
    pub now_to_deadline_delta: Option<i64>,
    pub frame_time_to_now_delta: Option<i64>,
    pub frame_time_to_deadline_delta: Option<i64>,
    pub now: Option<i64>,
    pub frame_time: Option<i64>,
    pub deadline: Option<i64>,
}

Fields

interval_delta: Option<i64>now_to_deadline_delta: Option<i64>frame_time_to_now_delta: Option<i64>frame_time_to_deadline_delta: Option<i64>now: Option<i64>frame_time: Option<i64>deadline: Option<i64>

Implementations

Source

impl TimestampsInUs

pub fn interval_delta(&self) -> i64

Returns the value of interval_delta, or the default value if interval_delta is unset.

pub fn now_to_deadline_delta(&self) -> i64

Returns the value of now_to_deadline_delta, or the default value if now_to_deadline_delta is unset.

pub fn frame_time_to_now_delta(&self) -> i64

Returns the value of frame_time_to_now_delta, or the default value if frame_time_to_now_delta is unset.

pub fn frame_time_to_deadline_delta(&self) -> i64

Returns the value of frame_time_to_deadline_delta, or the default value if frame_time_to_deadline_delta is unset.

pub fn now(&self) -> i64

Returns the value of now, or the default value if now is unset.

pub fn frame_time(&self) -> i64

Returns the value of frame_time, or the default value if frame_time is unset.

pub fn deadline(&self) -> i64

Returns the value of deadline, or the default value if deadline is unset.