pub struct AbsInfo {
pub minimum: Option<i32>,
pub maximum: Option<i32>,
pub fuzz: Option<i32>,
pub flat: Option<i32>,
pub resolution: Option<i32>,
}Expand description
Proto version of Linux’s struct input_absinfo, excluding the value field (which is tracked elsewhere).
Next ID: 6
Fields
minimum: Option<i32>maximum: Option<i32>fuzz: Option<i32>flat: Option<i32>resolution: Option<i32>Implementations
Sourceimpl AbsInfo
impl AbsInfo
Sourcepub fn minimum(&self) -> i32
pub fn minimum(&self) -> i32
Returns the value of minimum, or the default value if minimum is unset.
Sourcepub fn maximum(&self) -> i32
pub fn maximum(&self) -> i32
Returns the value of maximum, or the default value if maximum is unset.
Sourcepub fn resolution(&self) -> i32
pub fn resolution(&self) -> i32
Returns the value of resolution, or the default value if resolution is unset.