pub struct AxisMap {
pub axis_states: HashMap<u32, i32>,
}Expand description
Contains the current values of all axes of a particular type (e.g. EV_ABS, EV_KEY, etc.).
Next ID: 2
Fields
axis_states: HashMap<u32, i32>Current values of all axes, other than ABS_MT_* axes (which have multiple slots), which are kept in abs_mt_states instead.
The keys are the Linux axis codes, e.g. ABS_* for absolute axes. If there is no entry for a particular axis, assume that its value is 0.