pub struct Identifier {
pub bustype: Option<u32>,
pub vendor: Option<u32>,
pub product: Option<u32>,
pub version: Option<u32>,
}Expand description
Proto version of Linux’s struct input_id. Although uint32s are used for the fields, the kernel uses 16-bit ints so values will be less than 2^16.
Next ID: 5
Fields
bustype: Option<u32>The bus that the device is connected to. Values will be one of Linux’s BUS_* constants.
vendor: Option<u32>A number identifying the vendor of the device. Often a USB or Bluetooth vendor ID, but not always.
product: Option<u32>version: Option<u32>Implementations
Sourceimpl Identifier
impl Identifier
Sourcepub fn bustype(&self) -> u32
pub fn bustype(&self) -> u32
Returns the value of bustype, or the default value if bustype is unset.
Sourcepub fn vendor(&self) -> u32
pub fn vendor(&self) -> u32
Returns the value of vendor, or the default value if vendor is unset.