pub struct DeviceRemoval {}Expand description
Describes an evdev device being removed from the system.
Next ID: 1
Empty — we don’t need to record any data other than the device ID for this event type.