pub enum Descriptor {
ExtensionSet(FileDescriptorSet),
ExtensionSetGzip(Vec<u8>),
}Variants
ExtensionSet(FileDescriptorSet)
ExtensionSetGzip(Vec<u8>)
Same as extension_set, but gzip-compressed. This is used by the tracing service on Android to emit pre-compressed descriptor files from /etc/tracing_descriptors.gz without decompressing them first.
Implementations
Sourceimpl Descriptor
impl Descriptor
Sourcepub fn merge<B>(
field: &mut Option<Descriptor>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Descriptor>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.