#[repr(i32)]pub enum LatchedFenceState {
LatchedUnknown = 0,
LatchedSignaled = 1,
LatchedUnsignaled = 2,
LatchedDelayedLatchUnsignaled = 3,
}Variants
Implementations
Sourceimpl LatchedFenceState
impl LatchedFenceState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.