CompactSched

Struct CompactSched 

pub struct CompactSched {
    pub intern_table: Vec<String>,
    pub switch_timestamp: Vec<u64>,
    pub switch_prev_state: Vec<i64>,
    pub switch_next_pid: Vec<i32>,
    pub switch_next_prio: Vec<i32>,
    pub switch_next_comm_index: Vec<u32>,
    pub waking_timestamp: Vec<u64>,
    pub waking_pid: Vec<i32>,
    pub waking_target_cpu: Vec<i32>,
    pub waking_prio: Vec<i32>,
    pub waking_comm_index: Vec<u32>,
    pub waking_common_flags: Vec<u32>,
}
Optionally-enabled compact encoding of a batch of scheduling events. Only a subset of events & their fields is recorded. All fields (except comms) are stored in a structure-of-arrays form, one entry in each repeated field per event.

Fields

intern_table: Vec<String>

Interned table of unique strings for this bundle.

switch_timestamp: Vec<u64>

Delta-encoded timestamps across all sched_switch events within this bundle. The first is absolute, each next one is relative to its predecessor.

switch_prev_state: Vec<i64>switch_next_pid: Vec<i32>switch_next_prio: Vec<i32>switch_next_comm_index: Vec<u32>

One per event, index into |intern_table| corresponding to the next_comm field of the event.

waking_timestamp: Vec<u64>

Delta-encoded timestamps across all sched_waking events within this bundle. The first is absolute, each next one is relative to its predecessor.

waking_pid: Vec<i32>waking_target_cpu: Vec<i32>waking_prio: Vec<i32>waking_comm_index: Vec<u32>

One per event, index into |intern_table| corresponding to the comm field of the event.

waking_common_flags: Vec<u32>