Thread

pub struct Thread {
    pub tid: Option<i64>,
    pub pid: Option<i64>,
    pub comm: Option<String>,
    pub is_main_thread: Option<bool>,
    pub is_idle: Option<bool>,
}
Representation of a thread.

Fields

tid: Option<i64>

Thread id.

pid: Option<i64>

Id of the parent process.

comm: Option<String>

The command name of the thread.

is_main_thread: Option<bool>

True if thread is the main thread.

is_idle: Option<bool>

True if thread is an idle thread.

Implementations

Source

impl Thread

pub fn tid(&self) -> i64

Returns the value of tid, or the default value if tid is unset.

pub fn pid(&self) -> i64

Returns the value of pid, or the default value if pid is unset.

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn is_main_thread(&self) -> bool

Returns the value of is_main_thread, or the default value if is_main_thread is unset.

pub fn is_idle(&self) -> bool

Returns the value of is_idle, or the default value if is_idle is unset.