pub enum Desc {
CounterDescriptor(GpuCounterDescriptor),
CounterDescriptorIid(u64),
}Expand description
The specification for the GPU counters. Gives them information like the name of the counter, unit etc.
Variants
CounterDescriptor(GpuCounterDescriptor)
Must be specified on first trace packet of each session if using mode 1. (e.g. if you’re an Android GPU vendor).
CounterDescriptorIid(u64)
ID to a InternedGpuCounterDescriptor in InternedData. Must be specified on first trace packet of the trusted sequence if using mode 2.
Implementations
Sourceimpl Desc
impl Desc
Sourcepub fn merge<B>(
field: &mut Option<Desc>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Desc>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.