pub struct Wakelock {
pub wakelock_id: Option<u32>,
pub wakelock_name: Option<String>,
pub wakelock_type: Option<i32>,
}Fields
wakelock_id: Option<u32>Interning id.
wakelock_name: Option<String>Name of the wakelock.
wakelock_type: Option<i32>Type of the wakelock. We record data about both true kernel wakelocks and “native” wakelocks which are taken in userspace but are more conceptually similar to kernel wakelocks than normal userspace ones.
Implementations
Sourceimpl Wakelock
impl Wakelock
Sourcepub fn wakelock_id(&self) -> u32
pub fn wakelock_id(&self) -> u32
Returns the value of wakelock_id, or the default value if wakelock_id is unset.
Sourcepub fn wakelock_name(&self) -> &str
pub fn wakelock_name(&self) -> &str
Returns the value of wakelock_name, or the default value if wakelock_name is unset.
Sourcepub fn wakelock_type(&self) -> Type
pub fn wakelock_type(&self) -> Type
Returns the enum value of wakelock_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_wakelock_type(&mut self, value: Type)
pub fn set_wakelock_type(&mut self, value: Type)
Sets wakelock_type to the provided enum value.