MemoryEdge

pub struct MemoryEdge {
    pub source_id: Option<u64>,
    pub target_id: Option<u64>,
    pub importance: Option<u32>,
    pub overridable: Option<bool>,
}
A directed edge that connects any 2 nodes in the graph above. These are in addition to the inherent edges added due to the tree structure of the node’s absolute names. Node with id |source_id| owns the node with id |target_id|, and has the effect of attributing the memory usage of target to source. |importance| is optional and relevant only for the cases of co-ownership, where it acts as a z-index: the owner with the highest importance will be attributed target’s memory.

Fields

source_id: Option<u64>target_id: Option<u64>importance: Option<u32>overridable: Option<bool>

Implementations

Source

impl MemoryEdge

pub fn source_id(&self) -> u64

Returns the value of source_id, or the default value if source_id is unset.

pub fn target_id(&self) -> u64

Returns the value of target_id, or the default value if target_id is unset.

pub fn importance(&self) -> u32

Returns the value of importance, or the default value if importance is unset.

pub fn overridable(&self) -> bool

Returns the value of overridable, or the default value if overridable is unset.