RailDescriptor

Struct RailDescriptor 

pub struct RailDescriptor {
    pub index: Option<u32>,
    pub rail_name: Option<String>,
    pub subsys_name: Option<String>,
    pub sampling_rate: Option<u32>,
}

Fields

index: Option<u32>

Index corresponding to the rail

rail_name: Option<String>

Name of the rail

subsys_name: Option<String>

Name of the subsystem to which this rail belongs

sampling_rate: Option<u32>

Hardware sampling rate (Hz).

Implementations

Source

impl RailDescriptor

pub fn index(&self) -> u32

Returns the value of index, or the default value if index is unset.

pub fn rail_name(&self) -> &str

Returns the value of rail_name, or the default value if rail_name is unset.

pub fn subsys_name(&self) -> &str

Returns the value of subsys_name, or the default value if subsys_name is unset.

pub fn sampling_rate(&self) -> u32

Returns the value of sampling_rate, or the default value if sampling_rate is unset.