Bucket

pub struct Bucket {
    pub upper_limit: Option<u64>,
    pub max_bucket: Option<bool>,
    pub count: Option<u64>,
}

Fields

upper_limit: Option<u64>

This bucket counts values from the previous bucket’s (or -infinity if this is the first bucket) upper_limit (inclusive) to this upper_limit (exclusive).

max_bucket: Option<bool>

This is the highest bucket. This is set instead of the upper_limit. Any values larger or equal to the previous bucket’s upper_limit are counted in this bucket.

count: Option<u64>

Number of values that fall into this range.

Implementations

Source

impl Bucket

pub fn upper_limit(&self) -> u64

Returns the value of upper_limit, or the default value if upper_limit is unset.

pub fn max_bucket(&self) -> bool

Returns the value of max_bucket, or the default value if max_bucket is unset.

pub fn count(&self) -> u64

Returns the value of count, or the default value if count is unset.