pub struct Change {
pub mode: Option<i32>,
pub layer_id: Option<i32>,
pub window_id: Option<i32>,
pub flags: Option<i32>,
pub start_display_id: Option<i32>,
pub end_display_id: Option<i32>,
pub start_rotation: Option<i32>,
pub end_rotation: Option<i32>,
pub start_absolute_bounds: Option<RectProto>,
pub end_absolute_bounds: Option<RectProto>,
}Expand description
Contains the information about the windows changed in a transition.
Fields
mode: Option<i32>The transition mode of this change (e.g. TO_FRONT, CLOSE…)
layer_id: Option<i32>The layer id of this change.
window_id: Option<i32>The window id of this change.
flags: Option<i32>The flags set on this change.
start_display_id: Option<i32>The display id the change is transitioning on before the transition.
end_display_id: Option<i32>The display id the change is transitioning on after the transition.
start_rotation: Option<i32>The rotation of the change before the transition.
end_rotation: Option<i32>The rotation of the change after the transition.
start_absolute_bounds: Option<RectProto>The absolute screen bounds of the change before the transition.
end_absolute_bounds: Option<RectProto>The absolute screen bounds of the change after the transition.
Implementations
Sourceimpl Change
impl Change
Sourcepub fn layer_id(&self) -> i32
pub fn layer_id(&self) -> i32
Returns the value of layer_id, or the default value if layer_id is unset.
Sourcepub fn window_id(&self) -> i32
pub fn window_id(&self) -> i32
Returns the value of window_id, or the default value if window_id is unset.
Sourcepub fn start_display_id(&self) -> i32
pub fn start_display_id(&self) -> i32
Returns the value of start_display_id, or the default value if start_display_id is unset.
Sourcepub fn end_display_id(&self) -> i32
pub fn end_display_id(&self) -> i32
Returns the value of end_display_id, or the default value if end_display_id is unset.
Sourcepub fn start_rotation(&self) -> i32
pub fn start_rotation(&self) -> i32
Returns the value of start_rotation, or the default value if start_rotation is unset.
Sourcepub fn end_rotation(&self) -> i32
pub fn end_rotation(&self) -> i32
Returns the value of end_rotation, or the default value if end_rotation is unset.