pub enum UnitField {
Unit(i32),
UnitStr(String),
}Expand description
The unit weights are expressed in. Set the well-known unit when one
fits, otherwise set unit_str to a custom label.
Variants
Unit(i32)
A well-known unit from the Unit enum.
UnitStr(String)
A custom unit label, used when no Unit enum value fits.
Implementations
Sourceimpl UnitField
impl UnitField
Sourcepub fn merge(
field: &mut Option<UnitField>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<UnitField>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.