pub enum ExecutionContextField {
ExecutionContext(ExecutionContext),
ExecutionContextIid(u64),
}Expand description
The execution state (cpu, privilege mode) at sample time. Absent for
samplers that observe off-CPU tasks. Give it inline via execution_context
or reference an interned ExecutionContext via execution_context_iid.
Variants
ExecutionContext(ExecutionContext)
Inline execution context.
ExecutionContextIid(u64)
Interned execution context, referencing InternedData.stack_sample_execution_contexts.
Implementations
Sourceimpl ExecutionContextField
impl ExecutionContextField
Sourcepub fn merge(
field: &mut Option<ExecutionContextField>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ExecutionContextField>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.