pub enum PrimaryDescriptorField {
PrimaryDescriptor(CounterDescriptor),
PrimaryDescriptorIid(u64),
}Expand description
The sampling timebase: the counter this sample’s weight is measured against. Set one of the two; may be omitted entirely if declared in StackSampleDefaults.primary_descriptor.
Variants
PrimaryDescriptor(CounterDescriptor)
Inline timebase descriptor.
PrimaryDescriptorIid(u64)
Interned timebase descriptor, referencing InternedData.stack_sample_counter_descriptors.
Implementations
Sourceimpl PrimaryDescriptorField
impl PrimaryDescriptorField
Sourcepub fn merge(
field: &mut Option<PrimaryDescriptorField>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<PrimaryDescriptorField>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.