pub enum TaskContextField {
TaskContext(TaskContext),
TaskContextIid(u64),
}Expand description
The task (thread / process / async context) this sample is attributed to.
Give it inline via task_context or reference an interned TaskContext via
task_context_iid.
Variants
TaskContext(TaskContext)
Inline task context.
TaskContextIid(u64)
Interned task context, referencing InternedData.stack_sample_task_contexts.
Implementations
Sourceimpl TaskContextField
impl TaskContextField
Sourcepub fn merge(
field: &mut Option<TaskContextField>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<TaskContextField>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.