#[repr(i32)]pub enum Unit {
Unspecified = 0,
Nanoseconds = 1,
CpuCycles = 2,
Instructions = 3,
Bytes = 4,
PageFaults = 5,
CacheMisses = 6,
CacheReferences = 7,
BranchMisses = 8,
Count = 9,
}Expand description
The unit a CounterDescriptor’s values are expressed in. Append-only: new units may be added, but existing values are never renumbered or repurposed. If none of these fit, set CounterDescriptor.unit_str instead.
Variants
Unspecified = 0
Nanoseconds = 1
CpuCycles = 2
Instructions = 3
Bytes = 4
PageFaults = 5
CacheMisses = 6
CacheReferences = 7
BranchMisses = 8
Count = 9
Implementations
Sourceimpl Unit
impl Unit
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.