pub struct TaskContext {
pub iid: Option<u64>,
pub pid: Option<u32>,
pub tid: Option<u32>,
pub async_id: Option<u64>,
}Expand description
The task an observation is attributed to. At least one of pid / tid / async_id should be set. async_id identifies a stackful async context (goroutine, fiber, …) described by an AsyncContextDescriptor whose iid equals the async_id.
Fields
iid: Option<u64>Interning key, used when this context is emitted via InternedData.stack_sample_task_contexts and referenced by StackSample.task_context_iid. Starts from 1; 0 is the same as “not set”.
pid: Option<u32>OS process id the sample belongs to.
tid: Option<u32>OS thread id the sample belongs to. If only tid is set, the process is inferred from thread association elsewhere in the trace.
async_id: Option<u64>Implementations
Sourceimpl TaskContext
impl TaskContext