pub struct AndroidAflags {
pub flags: Vec<Flag>,
pub error: Option<String>,
}Expand description
Android aconfig flags (aflags). This message captures a snapshot of the state of aconfig flags on the device. Keep in sync with: http://ac/packages/modules/ConfigInfrastructure/aflags/proto/aflags.proto
Fields
flags: Vec<Flag>A collection of flags.
error: Option<String>A human-readable error logged if aflags processing fails. This is a perfetto specific field used to help debugging.
Implementations