AndroidEnergyConsumer

Struct AndroidEnergyConsumer 

pub struct AndroidEnergyConsumer {
    pub energy_consumer_id: Option<i32>,
    pub ordinal: Option<i32>,
    pub type: Option<String>,
    pub name: Option<String>,
}
Energy consumer based on aidl class: android.hardware.power.stats.EnergyConsumer.

Fields

energy_consumer_id: Option<i32>

Unique ID of this energy consumer. Matches the ID in a AndroidEnergyEstimationBreakdown.

ordinal: Option<i32>

For a group of energy consumers of the same logical type, sorting by ordinal gives their physical order. Ordinals must be consecutive integers starting from 0.

type: Option<String>

Type of this energy consumer.

name: Option<String>

Unique name of this energy consumer. Vendor/device specific. Opaque to framework.

Implementations

Source

impl AndroidEnergyConsumer

pub fn energy_consumer_id(&self) -> i32

Returns the value of energy_consumer_id, or the default value if energy_consumer_id is unset.

pub fn ordinal(&self) -> i32

Returns the value of ordinal, or the default value if ordinal is unset.

pub fn type(&self) -> &str

Returns the value of type, or the default value if type is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.