AndroidFsDatareadStartFtraceEvent

Struct AndroidFsDatareadStartFtraceEvent 

pub struct AndroidFsDatareadStartFtraceEvent {
    pub bytes: Option<i32>,
    pub cmdline: Option<String>,
    pub i_size: Option<i64>,
    pub ino: Option<u64>,
    pub offset: Option<i64>,
    pub pathbuf: Option<String>,
    pub pid: Option<i32>,
}

Fields

bytes: Option<i32>cmdline: Option<String>i_size: Option<i64>ino: Option<u64>offset: Option<i64>pathbuf: Option<String>pid: Option<i32>

Implementations

Source

impl AndroidFsDatareadStartFtraceEvent

pub fn bytes(&self) -> i32

Returns the value of bytes, or the default value if bytes is unset.

pub fn cmdline(&self) -> &str

Returns the value of cmdline, or the default value if cmdline is unset.

pub fn i_size(&self) -> i64

Returns the value of i_size, or the default value if i_size is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn offset(&self) -> i64

Returns the value of offset, or the default value if offset is unset.

pub fn pathbuf(&self) -> &str

Returns the value of pathbuf, or the default value if pathbuf is unset.

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.