AndroidFsDatawriteEndFtraceEvent

Struct AndroidFsDatawriteEndFtraceEvent 

pub struct AndroidFsDatawriteEndFtraceEvent {
    pub bytes: Option<i32>,
    pub ino: Option<u64>,
    pub offset: Option<i64>,
}

Fields

bytes: Option<i32>ino: Option<u64>offset: Option<i64>

Implementations

Source

impl AndroidFsDatawriteEndFtraceEvent

pub fn bytes(&self) -> i32

Returns the value of bytes, or the default value if bytes is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn offset(&self) -> i64

Returns the value of offset, or the default value if offset is unset.