pub struct ArtProcessMetadata {
pub pid: Option<i32>,
pub uid: Option<i32>,
pub process_name: Option<String>,
pub package_name: Option<String>,
pub oom_allocation_size: Option<u64>,
pub oom_total_bytes_free: Option<u64>,
pub oom_free_bytes_until_oom: Option<u64>,
pub oom_thread_java_stack: Option<JavaStack>,
pub oom_error_msg: Option<String>,
}Fields
pid: Option<i32>uid: Option<i32>process_name: Option<String>/proc/self/cmdline argv0
package_name: Option<String>Set by VMRuntime.setProcessPackageName
oom_allocation_size: Option<u64>OutOfMemoryError details (if heap dump was triggered by an OOM) The size of the allocation that ended up failing with OOME
oom_total_bytes_free: Option<u64>Amount of free memory until the runtime would need to grow the heap
oom_free_bytes_until_oom: Option<u64>Amount of memory remaining until the max heap size supported
oom_thread_java_stack: Option<JavaStack>Stacktrace for the thread doing the failing allocation
oom_error_msg: Option<String>Full OOME exception message
Implementations
Sourceimpl ArtProcessMetadata
impl ArtProcessMetadata
Sourcepub fn process_name(&self) -> &str
pub fn process_name(&self) -> &str
Returns the value of process_name, or the default value if process_name is unset.
Sourcepub fn package_name(&self) -> &str
pub fn package_name(&self) -> &str
Returns the value of package_name, or the default value if package_name is unset.
Sourcepub fn oom_allocation_size(&self) -> u64
pub fn oom_allocation_size(&self) -> u64
Returns the value of oom_allocation_size, or the default value if oom_allocation_size is unset.
Sourcepub fn oom_total_bytes_free(&self) -> u64
pub fn oom_total_bytes_free(&self) -> u64
Returns the value of oom_total_bytes_free, or the default value if oom_total_bytes_free is unset.
Sourcepub fn oom_free_bytes_until_oom(&self) -> u64
pub fn oom_free_bytes_until_oom(&self) -> u64
Returns the value of oom_free_bytes_until_oom, or the default value if oom_free_bytes_until_oom is unset.
Sourcepub fn oom_error_msg(&self) -> &str
pub fn oom_error_msg(&self) -> &str
Returns the value of oom_error_msg, or the default value if oom_error_msg is unset.