BclIrqTriggerFtraceEvent

Struct BclIrqTriggerFtraceEvent 

pub struct BclIrqTriggerFtraceEvent {
    pub id: Option<i32>,
    pub throttle: Option<i32>,
    pub cpu0_limit: Option<i32>,
    pub cpu1_limit: Option<i32>,
    pub cpu2_limit: Option<i32>,
    pub tpu_limit: Option<i32>,
    pub gpu_limit: Option<i32>,
    pub voltage: Option<i32>,
    pub capacity: Option<i32>,
}

Fields

id: Option<i32>throttle: Option<i32>cpu0_limit: Option<i32>cpu1_limit: Option<i32>cpu2_limit: Option<i32>tpu_limit: Option<i32>gpu_limit: Option<i32>voltage: Option<i32>capacity: Option<i32>

Implementations

Source

impl BclIrqTriggerFtraceEvent

pub fn id(&self) -> i32

Returns the value of id, or the default value if id is unset.

pub fn throttle(&self) -> i32

Returns the value of throttle, or the default value if throttle is unset.

pub fn cpu0_limit(&self) -> i32

Returns the value of cpu0_limit, or the default value if cpu0_limit is unset.

pub fn cpu1_limit(&self) -> i32

Returns the value of cpu1_limit, or the default value if cpu1_limit is unset.

pub fn cpu2_limit(&self) -> i32

Returns the value of cpu2_limit, or the default value if cpu2_limit is unset.

pub fn tpu_limit(&self) -> i32

Returns the value of tpu_limit, or the default value if tpu_limit is unset.

pub fn gpu_limit(&self) -> i32

Returns the value of gpu_limit, or the default value if gpu_limit is unset.

pub fn voltage(&self) -> i32

Returns the value of voltage, or the default value if voltage is unset.

pub fn capacity(&self) -> i32

Returns the value of capacity, or the default value if capacity is unset.