BinderTransactionFtraceEvent

Struct BinderTransactionFtraceEvent 

pub struct BinderTransactionFtraceEvent {
    pub debug_id: Option<i32>,
    pub target_node: Option<i32>,
    pub to_proc: Option<i32>,
    pub to_thread: Option<i32>,
    pub reply: Option<i32>,
    pub code: Option<u32>,
    pub flags: Option<u32>,
}

Fields

debug_id: Option<i32>target_node: Option<i32>to_proc: Option<i32>to_thread: Option<i32>reply: Option<i32>code: Option<u32>flags: Option<u32>

Implementations

Source

impl BinderTransactionFtraceEvent

pub fn debug_id(&self) -> i32

Returns the value of debug_id, or the default value if debug_id is unset.

pub fn target_node(&self) -> i32

Returns the value of target_node, or the default value if target_node is unset.

pub fn to_proc(&self) -> i32

Returns the value of to_proc, or the default value if to_proc is unset.

pub fn to_thread(&self) -> i32

Returns the value of to_thread, or the default value if to_thread is unset.

pub fn reply(&self) -> i32

Returns the value of reply, or the default value if reply is unset.

pub fn code(&self) -> u32

Returns the value of code, or the default value if code is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.