BlockRqRequeueFtraceEvent

Struct BlockRqRequeueFtraceEvent 

pub struct BlockRqRequeueFtraceEvent {
    pub dev: Option<u64>,
    pub sector: Option<u64>,
    pub nr_sector: Option<u32>,
    pub errors: Option<i32>,
    pub rwbs: Option<String>,
    pub cmd: Option<String>,
}

Fields

dev: Option<u64>sector: Option<u64>nr_sector: Option<u32>errors: Option<i32>rwbs: Option<String>cmd: Option<String>

Implementations

Source

impl BlockRqRequeueFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn sector(&self) -> u64

Returns the value of sector, or the default value if sector is unset.

pub fn nr_sector(&self) -> u32

Returns the value of nr_sector, or the default value if nr_sector is unset.

pub fn errors(&self) -> i32

Returns the value of errors, or the default value if errors is unset.

pub fn rwbs(&self) -> &str

Returns the value of rwbs, or the default value if rwbs is unset.

pub fn cmd(&self) -> &str

Returns the value of cmd, or the default value if cmd is unset.