CgroupAttachTaskFtraceEvent

Struct CgroupAttachTaskFtraceEvent 

pub struct CgroupAttachTaskFtraceEvent {
    pub dst_root: Option<i32>,
    pub dst_id: Option<i32>,
    pub pid: Option<i32>,
    pub comm: Option<String>,
    pub cname: Option<String>,
    pub dst_level: Option<i32>,
    pub dst_path: Option<String>,
}

Fields

dst_root: Option<i32>dst_id: Option<i32>pid: Option<i32>comm: Option<String>cname: Option<String>dst_level: Option<i32>dst_path: Option<String>

Implementations

Source

impl CgroupAttachTaskFtraceEvent

pub fn dst_root(&self) -> i32

Returns the value of dst_root, or the default value if dst_root is unset.

pub fn dst_id(&self) -> i32

Returns the value of dst_id, or the default value if dst_id is unset.

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn cname(&self) -> &str

Returns the value of cname, or the default value if cname is unset.

pub fn dst_level(&self) -> i32

Returns the value of dst_level, or the default value if dst_level is unset.

pub fn dst_path(&self) -> &str

Returns the value of dst_path, or the default value if dst_path is unset.