ChromeBenchmarkMetadata

Struct ChromeBenchmarkMetadata 

pub struct ChromeBenchmarkMetadata {
    pub benchmark_start_time_us: Option<i64>,
    pub story_run_time_us: Option<i64>,
    pub benchmark_name: Option<String>,
    pub benchmark_description: Option<String>,
    pub label: Option<String>,
    pub story_name: Option<String>,
    pub story_tags: Vec<String>,
    pub story_run_index: Option<i32>,
    pub had_failures: Option<bool>,
}
This message is not intended to be written by the chrome on the device. It’s emitted on the host by the telemetry benchmark infrastructure (it’s a part of the trace that’s written by the telemetry tracing agent).

Fields

benchmark_start_time_us: Option<i64>

Time when the benchmark execution started (host unixtime in microseconds).

story_run_time_us: Option<i64>

Time when this particular story was run (host unixtime in microseconds).

benchmark_name: Option<String>

Name of benchmark.

benchmark_description: Option<String>

Description of benchmark.

label: Option<String>

Optional label.

story_name: Option<String>

Name of story.

story_tags: Vec<String>

List of story tags.

story_run_index: Option<i32>

Index of the story run (>0 if the same story was run several times).

had_failures: Option<bool>

Whether this run failed.

Implementations

Source

impl ChromeBenchmarkMetadata

pub fn benchmark_start_time_us(&self) -> i64

Returns the value of benchmark_start_time_us, or the default value if benchmark_start_time_us is unset.

pub fn story_run_time_us(&self) -> i64

Returns the value of story_run_time_us, or the default value if story_run_time_us is unset.

pub fn benchmark_name(&self) -> &str

Returns the value of benchmark_name, or the default value if benchmark_name is unset.

pub fn benchmark_description(&self) -> &str

Returns the value of benchmark_description, or the default value if benchmark_description is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn story_name(&self) -> &str

Returns the value of story_name, or the default value if story_name is unset.

pub fn story_run_index(&self) -> i32

Returns the value of story_run_index, or the default value if story_run_index is unset.

pub fn had_failures(&self) -> bool

Returns the value of had_failures, or the default value if had_failures is unset.