ChromeCompositorSchedulerState

Struct ChromeCompositorSchedulerState 

pub struct ChromeCompositorSchedulerState {
Show 16 fields pub state_machine: Option<ChromeCompositorStateMachine>, pub observing_begin_frame_source: Option<bool>, pub begin_impl_frame_deadline_task: Option<bool>, pub pending_begin_frame_task: Option<bool>, pub skipped_last_frame_missed_exceeded_deadline: Option<bool>, pub inside_action: Option<i32>, pub deadline_mode: Option<i32>, pub deadline_us: Option<i64>, pub deadline_scheduled_at_us: Option<i64>, pub now_us: Option<i64>, pub now_to_deadline_delta_us: Option<i64>, pub now_to_deadline_scheduled_at_delta_us: Option<i64>, pub begin_impl_frame_args: Option<BeginImplFrameArgs>, pub begin_frame_observer_state: Option<BeginFrameObserverState>, pub begin_frame_source_state: Option<BeginFrameSourceState>, pub compositor_timing_history: Option<CompositorTimingHistory>,
}
Next id: 18

Fields

state_machine: Option<ChromeCompositorStateMachine>observing_begin_frame_source: Option<bool>begin_impl_frame_deadline_task: Option<bool>pending_begin_frame_task: Option<bool>skipped_last_frame_missed_exceeded_deadline: Option<bool>inside_action: Option<i32>deadline_mode: Option<i32>deadline_us: Option<i64>deadline_scheduled_at_us: Option<i64>now_us: Option<i64>now_to_deadline_delta_us: Option<i64>now_to_deadline_scheduled_at_delta_us: Option<i64>begin_impl_frame_args: Option<BeginImplFrameArgs>begin_frame_observer_state: Option<BeginFrameObserverState>begin_frame_source_state: Option<BeginFrameSourceState>compositor_timing_history: Option<CompositorTimingHistory>

Implementations

Source

impl ChromeCompositorSchedulerState

pub fn observing_begin_frame_source(&self) -> bool

Returns the value of observing_begin_frame_source, or the default value if observing_begin_frame_source is unset.

pub fn begin_impl_frame_deadline_task(&self) -> bool

Returns the value of begin_impl_frame_deadline_task, or the default value if begin_impl_frame_deadline_task is unset.

pub fn pending_begin_frame_task(&self) -> bool

Returns the value of pending_begin_frame_task, or the default value if pending_begin_frame_task is unset.

pub fn skipped_last_frame_missed_exceeded_deadline(&self) -> bool

Returns the value of skipped_last_frame_missed_exceeded_deadline, or the default value if skipped_last_frame_missed_exceeded_deadline is unset.

pub fn inside_action(&self) -> ChromeCompositorSchedulerAction

Returns the enum value of inside_action, or the default if the field is unset or set to an invalid enum value.

pub fn set_inside_action(&mut self, value: ChromeCompositorSchedulerAction)

Sets inside_action to the provided enum value.

pub fn deadline_mode(&self) -> BeginImplFrameDeadlineMode

Returns the enum value of deadline_mode, or the default if the field is unset or set to an invalid enum value.

pub fn set_deadline_mode(&mut self, value: BeginImplFrameDeadlineMode)

Sets deadline_mode to the provided enum value.

pub fn deadline_us(&self) -> i64

Returns the value of deadline_us, or the default value if deadline_us is unset.

pub fn deadline_scheduled_at_us(&self) -> i64

Returns the value of deadline_scheduled_at_us, or the default value if deadline_scheduled_at_us is unset.

pub fn now_us(&self) -> i64

Returns the value of now_us, or the default value if now_us is unset.

pub fn now_to_deadline_delta_us(&self) -> i64

Returns the value of now_to_deadline_delta_us, or the default value if now_to_deadline_delta_us is unset.

pub fn now_to_deadline_scheduled_at_delta_us(&self) -> i64

Returns the value of now_to_deadline_scheduled_at_delta_us, or the default value if now_to_deadline_scheduled_at_delta_us is unset.