ChromeFrameReporter

Struct ChromeFrameReporter 

pub struct ChromeFrameReporter {
Show 18 fields pub state: Option<i32>, pub reason: Option<i32>, pub frame_source: Option<u64>, pub frame_sequence: Option<u64>, pub affects_smoothness: Option<bool>, pub scroll_state: Option<i32>, pub has_main_animation: Option<bool>, pub has_compositor_animation: Option<bool>, pub has_smooth_input_main: Option<bool>, pub has_missing_content: Option<bool>, pub layer_tree_host_id: Option<u64>, pub has_high_latency: Option<bool>, pub frame_type: Option<i32>, pub high_latency_contribution_stage: Vec<String>, pub checkerboarded_needs_raster: Option<bool>, pub checkerboarded_needs_record: Option<bool>, pub surface_frame_trace_id: Option<i64>, pub display_trace_id: Option<i64>,
}
DEPRECATED. Only kept for backwards compatibility. Use |ChromeFrameReporter2| in https://source.chromium.org/chromium/chromium/src/+/main:base/tracing/protos/chrome_track_event.proto instead.

Fields

state: Option<i32>reason: Option<i32>

The reason is set only if |state| is not |STATE_UPDATED_ALL|.

frame_source: Option<u64>frame_sequence: Option<u64>affects_smoothness: Option<bool>

If this is a droped frame (i.e. if |state| is set to |STATE_DROPPED| or |STATE_PRESENTED_PARTIAL|), then indicates whether this frame impacts smoothness.

scroll_state: Option<i32>

The type of active scroll.

has_main_animation: Option<bool>

If any main thread animation is active during this frame.

has_compositor_animation: Option<bool>

If any compositor thread animation is active during this frame.

has_smooth_input_main: Option<bool>

If any touch-driven UX (not scroll) is active during this frame.

has_missing_content: Option<bool>

Whether the frame contained any missing content (i.e. whether there was checkerboarding in the frame). If has_missing_content, checkerboarded_needs_raster and checkerboarded_needs_record all have values, has_missing_content should equal checkerboarded_needs_raster || checkerboarded_needs_record.

layer_tree_host_id: Option<u64>

The id of layer_tree_host that the frame has been produced for.

has_high_latency: Option<bool>

If total latency of PipelineReporter exceeds a certain limit.

frame_type: Option<i32>

Indicate if the frame is “FORKED” (i.e. a PipelineReporter event starts at the same frame sequence as another PipelineReporter) or “BACKFILL” (i.e. dropped frames when there are no partial compositor updates).

high_latency_contribution_stage: Vec<String>

The breakdown stage of PipelineReporter that is most likely accountable for high latency.

checkerboarded_needs_raster: Option<bool>

Whether the frame contained any content that is not fully rastered.

checkerboarded_needs_record: Option<bool>

Whether the frame contained any content that is not fully recorded.

surface_frame_trace_id: Option<i64>

viz::BeginFrameArgs.trace_id of the frame (before surface aggregation). See also ChromeTrackEvent.EventLatency.surface_frame_trace_id.

display_trace_id: Option<i64>

gfx::PresentationFeedback.display_trace_id of the frame (after surface aggregation). See also ChromeTrackEvent.EventLatency.display_trace_id.

Implementations

Source

impl ChromeFrameReporter

pub fn state(&self) -> State

Returns the enum value of state, or the default if the field is unset or set to an invalid enum value.

pub fn set_state(&mut self, value: State)

Sets state to the provided enum value.

pub fn reason(&self) -> FrameDropReason

Returns the enum value of reason, or the default if the field is unset or set to an invalid enum value.

pub fn set_reason(&mut self, value: FrameDropReason)

Sets reason to the provided enum value.

pub fn frame_source(&self) -> u64

Returns the value of frame_source, or the default value if frame_source is unset.

pub fn frame_sequence(&self) -> u64

Returns the value of frame_sequence, or the default value if frame_sequence is unset.

pub fn affects_smoothness(&self) -> bool

Returns the value of affects_smoothness, or the default value if affects_smoothness is unset.

pub fn scroll_state(&self) -> ScrollState

Returns the enum value of scroll_state, or the default if the field is unset or set to an invalid enum value.

pub fn set_scroll_state(&mut self, value: ScrollState)

Sets scroll_state to the provided enum value.

pub fn has_main_animation(&self) -> bool

Returns the value of has_main_animation, or the default value if has_main_animation is unset.

pub fn has_compositor_animation(&self) -> bool

Returns the value of has_compositor_animation, or the default value if has_compositor_animation is unset.

pub fn has_smooth_input_main(&self) -> bool

Returns the value of has_smooth_input_main, or the default value if has_smooth_input_main is unset.

pub fn has_missing_content(&self) -> bool

Returns the value of has_missing_content, or the default value if has_missing_content is unset.

pub fn layer_tree_host_id(&self) -> u64

Returns the value of layer_tree_host_id, or the default value if layer_tree_host_id is unset.

pub fn has_high_latency(&self) -> bool

Returns the value of has_high_latency, or the default value if has_high_latency is unset.

pub fn frame_type(&self) -> FrameType

Returns the enum value of frame_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_frame_type(&mut self, value: FrameType)

Sets frame_type to the provided enum value.

pub fn checkerboarded_needs_raster(&self) -> bool

Returns the value of checkerboarded_needs_raster, or the default value if checkerboarded_needs_raster is unset.

pub fn checkerboarded_needs_record(&self) -> bool

Returns the value of checkerboarded_needs_record, or the default value if checkerboarded_needs_record is unset.

pub fn surface_frame_trace_id(&self) -> i64

Returns the value of surface_frame_trace_id, or the default value if surface_frame_trace_id is unset.

pub fn display_trace_id(&self) -> i64

Returns the value of display_trace_id, or the default value if display_trace_id is unset.