ChromeHistogramSample

Struct ChromeHistogramSample 

pub struct ChromeHistogramSample {
    pub name_hash: Option<u64>,
    pub name: Option<String>,
    pub sample: Option<i64>,
    pub name_iid: Option<u64>,
}
An individual histogram sample logged via Chrome’s UMA metrics system.

Fields

name_hash: Option<u64>

MD5 hash of the metric name. Either |name_hash| or |name|/|name_iid| or both must be present.

name: Option<String>sample: Option<i64>name_iid: Option<u64>

Interned HistogramName. Only one of |name|, |name_iid| can be set.

Implementations

Source

impl ChromeHistogramSample

pub fn name_hash(&self) -> u64

Returns the value of name_hash, or the default value if name_hash is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn sample(&self) -> i64

Returns the value of sample, or the default value if sample is unset.

pub fn name_iid(&self) -> u64

Returns the value of name_iid, or the default value if name_iid is unset.