pub struct ChromeMetadataPacket {
pub background_tracing_metadata: Option<BackgroundTracingMetadata>,
pub chrome_version_code: Option<i32>,
pub enabled_categories: Option<String>,
pub field_trial_hashes: Vec<FinchHash>,
pub app_package_name: Option<String>,
pub app_version: Option<String>,
pub channel: Option<u32>,
pub os_name: Option<String>,
}Expand description
Metadata for chrome traces.
Fields
background_tracing_metadata: Option<BackgroundTracingMetadata>chrome_version_code: Option<i32>Version code of Chrome used by Android’s Play Store. This field is only set on Android.
enabled_categories: Option<String>Comma separated list of enabled categories for tracing. The list of possible category strings are listed in code base/trace_event/builtin_categories.h.
field_trial_hashes: Vec<FinchHash>List of Finch study/groups that apply to this trace.
app_package_name: Option<String>The package name of the app which is being traced. This field is only set on Android.
app_version: Option<String>A version number string for Chrome. This matches SystemProfileProto::app_version.
channel: Option<u32>This matches SystemProfileProto::channel.
os_name: Option<String>The user’s operating system. This matches SystemProfileProto::OS::name.
Implementations
Sourceimpl ChromeMetadataPacket
impl ChromeMetadataPacket
Sourcepub fn chrome_version_code(&self) -> i32
pub fn chrome_version_code(&self) -> i32
Returns the value of chrome_version_code, or the default value if chrome_version_code is unset.
Sourcepub fn enabled_categories(&self) -> &str
pub fn enabled_categories(&self) -> &str
Returns the value of enabled_categories, or the default value if enabled_categories is unset.
Sourcepub fn app_package_name(&self) -> &str
pub fn app_package_name(&self) -> &str
Returns the value of app_package_name, or the default value if app_package_name is unset.
Sourcepub fn app_version(&self) -> &str
pub fn app_version(&self) -> &str
Returns the value of app_version, or the default value if app_version is unset.