ChromeTrigger

Struct ChromeTrigger 

pub struct ChromeTrigger {
    pub trigger_name: Option<String>,
    pub trigger_name_hash: Option<u32>,
    pub flow_id: Option<u64>,
}
Information about a specific trigger during a background tracing scenario Associated packet timestamps are useful to delimitate a scenario range in a trace. Triggers are also useful for filtering traces.

Fields

trigger_name: Option<String>

Name of the trigger which was received.

trigger_name_hash: Option<u32>

SHA1 hash of the trigger name.

flow_id: Option<u64>

Flow id which should terminate on this trigger.

Implementations

Source

impl ChromeTrigger

pub fn trigger_name(&self) -> &str

Returns the value of trigger_name, or the default value if trigger_name is unset.

pub fn trigger_name_hash(&self) -> u32

Returns the value of trigger_name_hash, or the default value if trigger_name_hash is unset.

pub fn flow_id(&self) -> u64

Returns the value of flow_id, or the default value if flow_id is unset.