ClockDisableFtraceEvent

Struct ClockDisableFtraceEvent 

pub struct ClockDisableFtraceEvent {
    pub name: Option<String>,
    pub state: Option<u64>,
    pub cpu_id: Option<u64>,
}

Fields

name: Option<String>state: Option<u64>cpu_id: Option<u64>

Implementations

Source

impl ClockDisableFtraceEvent

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn state(&self) -> u64

Returns the value of state, or the default value if state is unset.

pub fn cpu_id(&self) -> u64

Returns the value of cpu_id, or the default value if cpu_id is unset.