CpuPerUidData

Struct CpuPerUidData 

pub struct CpuPerUidData {
    pub cluster_count: Option<u32>,
    pub uid: Vec<u32>,
    pub total_time_ms: Vec<u64>,
}

Fields

cluster_count: Option<u32>

Number of clusters in the device. This will only be filled in the first packet in a sequence.

uid: Vec<u32>

The UIDs for which we have data in this packet.

total_time_ms: Vec<u64>

List of times for {UID, cluster} tuples. This will be cluster_count times as long as the UID list.

Ordered like: [{UID 0, cluster 0}, {UID 0, cluster 1}, {UID 0, cluster 2}, {UID 1, cluster 0}, {UID 1, cluster 1}, {UID 1, cluster 2}, …]

Each value is an absolute count for the first packet in a sequence, and a delta thereafter. UIDs for which all clusters have a zero delta are omitted; a single non-zero value for any cluster for a UID will cause values for all clusters to be recorded.

Implementations

Source

impl CpuPerUidData

pub fn cluster_count(&self) -> u32

Returns the value of cluster_count, or the default value if cluster_count is unset.