CpuhpPauseFtraceEvent

Struct CpuhpPauseFtraceEvent 

pub struct CpuhpPauseFtraceEvent {
    pub active_cpus: Option<u32>,
    pub cpus: Option<u32>,
    pub pause: Option<u32>,
    pub time: Option<u32>,
}

Fields

active_cpus: Option<u32>cpus: Option<u32>pause: Option<u32>time: Option<u32>

Implementations

Source

impl CpuhpPauseFtraceEvent

pub fn active_cpus(&self) -> u32

Returns the value of active_cpus, or the default value if active_cpus is unset.

pub fn cpus(&self) -> u32

Returns the value of cpus, or the default value if cpus is unset.

pub fn pause(&self) -> u32

Returns the value of pause, or the default value if pause is unset.

pub fn time(&self) -> u32

Returns the value of time, or the default value if time is unset.