DevicePmCallbackStartFtraceEvent

Struct DevicePmCallbackStartFtraceEvent 

pub struct DevicePmCallbackStartFtraceEvent {
    pub device: Option<String>,
    pub driver: Option<String>,
    pub parent: Option<String>,
    pub pm_ops: Option<String>,
    pub event: Option<i32>,
}

Fields

device: Option<String>driver: Option<String>parent: Option<String>pm_ops: Option<String>event: Option<i32>

Implementations

Source

impl DevicePmCallbackStartFtraceEvent

pub fn device(&self) -> &str

Returns the value of device, or the default value if device is unset.

pub fn driver(&self) -> &str

Returns the value of driver, or the default value if driver is unset.

pub fn parent(&self) -> &str

Returns the value of parent, or the default value if parent is unset.

pub fn pm_ops(&self) -> &str

Returns the value of pm_ops, or the default value if pm_ops is unset.

pub fn event(&self) -> i32

Returns the value of event, or the default value if event is unset.