DmaFenceWaitStartFtraceEvent

Struct DmaFenceWaitStartFtraceEvent 

pub struct DmaFenceWaitStartFtraceEvent {
    pub context: Option<u32>,
    pub driver: Option<String>,
    pub seqno: Option<u32>,
    pub timeline: Option<String>,
}

Fields

context: Option<u32>driver: Option<String>seqno: Option<u32>timeline: Option<String>

Implementations

Source

impl DmaFenceWaitStartFtraceEvent

pub fn context(&self) -> u32

Returns the value of context, or the default value if context is unset.

pub fn driver(&self) -> &str

Returns the value of driver, or the default value if driver is unset.

pub fn seqno(&self) -> u32

Returns the value of seqno, or the default value if seqno is unset.

pub fn timeline(&self) -> &str

Returns the value of timeline, or the default value if timeline is unset.