DmaHeapStatFtraceEvent

Struct DmaHeapStatFtraceEvent 

pub struct DmaHeapStatFtraceEvent {
    pub inode: Option<u64>,
    pub len: Option<i64>,
    pub total_allocated: Option<u64>,
}

Fields

inode: Option<u64>len: Option<i64>total_allocated: Option<u64>

Implementations

Source

impl DmaHeapStatFtraceEvent

pub fn inode(&self) -> u64

Returns the value of inode, or the default value if inode is unset.

pub fn len(&self) -> i64

Returns the value of len, or the default value if len is unset.

pub fn total_allocated(&self) -> u64

Returns the value of total_allocated, or the default value if total_allocated is unset.