DpuDsiTxFtraceEvent

Struct DpuDsiTxFtraceEvent 

pub struct DpuDsiTxFtraceEvent {
    pub type: Option<u32>,
    pub last: Option<u32>,
    pub delay_ms: Option<u32>,
    pub tx_buf: Option<Vec<u8>>,
}

Fields

type: Option<u32>last: Option<u32>delay_ms: Option<u32>tx_buf: Option<Vec<u8>>

Implementations

Source

impl DpuDsiTxFtraceEvent

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn last(&self) -> u32

Returns the value of last, or the default value if last is unset.

pub fn delay_ms(&self) -> u32

Returns the value of delay_ms, or the default value if delay_ms is unset.

pub fn tx_buf(&self) -> &[u8]

Returns the value of tx_buf, or the default value if tx_buf is unset.