DrmSchedJobFtraceEvent

Struct DrmSchedJobFtraceEvent 

pub struct DrmSchedJobFtraceEvent {
    pub entity: Option<u64>,
    pub fence: Option<u64>,
    pub hw_job_count: Option<i32>,
    pub id: Option<u64>,
    pub job_count: Option<u32>,
    pub name: Option<String>,
}

Fields

entity: Option<u64>fence: Option<u64>hw_job_count: Option<i32>id: Option<u64>job_count: Option<u32>name: Option<String>

Implementations

Source

impl DrmSchedJobFtraceEvent

pub fn entity(&self) -> u64

Returns the value of entity, or the default value if entity is unset.

pub fn fence(&self) -> u64

Returns the value of fence, or the default value if fence is unset.

pub fn hw_job_count(&self) -> i32

Returns the value of hw_job_count, or the default value if hw_job_count is unset.

pub fn id(&self) -> u64

Returns the value of id, or the default value if id is unset.

pub fn job_count(&self) -> u32

Returns the value of job_count, or the default value if job_count is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.