DrmVblankEventFtraceEvent

Struct DrmVblankEventFtraceEvent 

pub struct DrmVblankEventFtraceEvent {
    pub crtc: Option<i32>,
    pub high_prec: Option<u32>,
    pub seq: Option<u32>,
    pub time: Option<i64>,
}

Fields

crtc: Option<i32>high_prec: Option<u32>seq: Option<u32>time: Option<i64>

Implementations

Source

impl DrmVblankEventFtraceEvent

pub fn crtc(&self) -> i32

Returns the value of crtc, or the default value if crtc is unset.

pub fn high_prec(&self) -> u32

Returns the value of high_prec, or the default value if high_prec is unset.

pub fn seq(&self) -> u32

Returns the value of seq, or the default value if seq is unset.

pub fn time(&self) -> i64

Returns the value of time, or the default value if time is unset.