Dwc3EventFtraceEvent

Struct Dwc3EventFtraceEvent 

pub struct Dwc3EventFtraceEvent {
    pub event: Option<u32>,
    pub ep0state: Option<u32>,
    pub str: Option<String>,
}

Fields

event: Option<u32>ep0state: Option<u32>str: Option<String>

Implementations

Source

impl Dwc3EventFtraceEvent

pub fn event(&self) -> u32

Returns the value of event, or the default value if event is unset.

pub fn ep0state(&self) -> u32

Returns the value of ep0state, or the default value if ep0state is unset.

pub fn str(&self) -> &str

Returns the value of str, or the default value if str is unset.