Dwc3GadgetEpCmdFtraceEvent

Struct Dwc3GadgetEpCmdFtraceEvent 

pub struct Dwc3GadgetEpCmdFtraceEvent {
    pub name: Option<String>,
    pub cmd: Option<u32>,
    pub param0: Option<u32>,
    pub param1: Option<u32>,
    pub param2: Option<u32>,
    pub cmd_status: Option<i32>,
}

Fields

name: Option<String>cmd: Option<u32>param0: Option<u32>param1: Option<u32>param2: Option<u32>cmd_status: Option<i32>

Implementations

Source

impl Dwc3GadgetEpCmdFtraceEvent

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn cmd(&self) -> u32

Returns the value of cmd, or the default value if cmd is unset.

pub fn param0(&self) -> u32

Returns the value of param0, or the default value if param0 is unset.

pub fn param1(&self) -> u32

Returns the value of param1, or the default value if param1 is unset.

pub fn param2(&self) -> u32

Returns the value of param2, or the default value if param2 is unset.

pub fn cmd_status(&self) -> i32

Returns the value of cmd_status, or the default value if cmd_status is unset.