Dwc3GadgetEpEnableFtraceEvent

Struct Dwc3GadgetEpEnableFtraceEvent 

pub struct Dwc3GadgetEpEnableFtraceEvent {
    pub name: Option<String>,
    pub maxpacket: Option<u32>,
    pub maxpacket_limit: Option<u32>,
    pub max_streams: Option<u32>,
    pub maxburst: Option<u32>,
    pub flags: Option<u32>,
    pub direction: Option<u32>,
    pub trb_enqueue: Option<u32>,
    pub trb_dequeue: Option<u32>,
}

Fields

name: Option<String>maxpacket: Option<u32>maxpacket_limit: Option<u32>max_streams: Option<u32>maxburst: Option<u32>flags: Option<u32>direction: Option<u32>trb_enqueue: Option<u32>trb_dequeue: Option<u32>

Implementations

Source

impl Dwc3GadgetEpEnableFtraceEvent

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn maxpacket(&self) -> u32

Returns the value of maxpacket, or the default value if maxpacket is unset.

pub fn maxpacket_limit(&self) -> u32

Returns the value of maxpacket_limit, or the default value if maxpacket_limit is unset.

pub fn max_streams(&self) -> u32

Returns the value of max_streams, or the default value if max_streams is unset.

pub fn maxburst(&self) -> u32

Returns the value of maxburst, or the default value if maxburst is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn direction(&self) -> u32

Returns the value of direction, or the default value if direction is unset.

pub fn trb_enqueue(&self) -> u32

Returns the value of trb_enqueue, or the default value if trb_enqueue is unset.

pub fn trb_dequeue(&self) -> u32

Returns the value of trb_dequeue, or the default value if trb_dequeue is unset.