Dwc3GadgetGivebackFtraceEvent

Struct Dwc3GadgetGivebackFtraceEvent 

pub struct Dwc3GadgetGivebackFtraceEvent {
    pub name: Option<String>,
    pub req: Option<u64>,
    pub actual: Option<u32>,
    pub length: Option<u32>,
    pub status: Option<i32>,
    pub zero: Option<i32>,
    pub short_not_ok: Option<i32>,
    pub no_interrupt: Option<i32>,
}

Fields

name: Option<String>req: Option<u64>actual: Option<u32>length: Option<u32>status: Option<i32>zero: Option<i32>short_not_ok: Option<i32>no_interrupt: Option<i32>

Implementations

Source

impl Dwc3GadgetGivebackFtraceEvent

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn req(&self) -> u64

Returns the value of req, or the default value if req is unset.

pub fn actual(&self) -> u32

Returns the value of actual, or the default value if actual is unset.

pub fn length(&self) -> u32

Returns the value of length, or the default value if length is unset.

pub fn status(&self) -> i32

Returns the value of status, or the default value if status is unset.

pub fn zero(&self) -> i32

Returns the value of zero, or the default value if zero is unset.

pub fn short_not_ok(&self) -> i32

Returns the value of short_not_ok, or the default value if short_not_ok is unset.

pub fn no_interrupt(&self) -> i32

Returns the value of no_interrupt, or the default value if no_interrupt is unset.