Dwc3PrepareTrbFtraceEvent

Struct Dwc3PrepareTrbFtraceEvent 

pub struct Dwc3PrepareTrbFtraceEvent {
    pub name: Option<String>,
    pub trb: Option<u64>,
    pub allocated: Option<u32>,
    pub queued: Option<u32>,
    pub bpl: Option<u32>,
    pub bph: Option<u32>,
    pub size: Option<u32>,
    pub ctrl: Option<u32>,
    pub type: Option<u32>,
    pub enqueue: Option<u32>,
    pub dequeue: Option<u32>,
}

Fields

name: Option<String>trb: Option<u64>allocated: Option<u32>queued: Option<u32>bpl: Option<u32>bph: Option<u32>size: Option<u32>ctrl: Option<u32>type: Option<u32>enqueue: Option<u32>dequeue: Option<u32>

Implementations

Source

impl Dwc3PrepareTrbFtraceEvent

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn trb(&self) -> u64

Returns the value of trb, or the default value if trb is unset.

pub fn allocated(&self) -> u32

Returns the value of allocated, or the default value if allocated is unset.

pub fn queued(&self) -> u32

Returns the value of queued, or the default value if queued is unset.

pub fn bpl(&self) -> u32

Returns the value of bpl, or the default value if bpl is unset.

pub fn bph(&self) -> u32

Returns the value of bph, or the default value if bph is unset.

pub fn size(&self) -> u32

Returns the value of size, or the default value if size is unset.

pub fn ctrl(&self) -> u32

Returns the value of ctrl, or the default value if ctrl is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn enqueue(&self) -> u32

Returns the value of enqueue, or the default value if enqueue is unset.

pub fn dequeue(&self) -> u32

Returns the value of dequeue, or the default value if dequeue is unset.