Ext4DaReleaseSpaceFtraceEvent

Struct Ext4DaReleaseSpaceFtraceEvent 

pub struct Ext4DaReleaseSpaceFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub i_blocks: Option<u64>,
    pub freed_blocks: Option<i32>,
    pub reserved_data_blocks: Option<i32>,
    pub reserved_meta_blocks: Option<i32>,
    pub allocated_meta_blocks: Option<i32>,
    pub mode: Option<u32>,
}

Fields

dev: Option<u64>ino: Option<u64>i_blocks: Option<u64>freed_blocks: Option<i32>reserved_data_blocks: Option<i32>reserved_meta_blocks: Option<i32>allocated_meta_blocks: Option<i32>mode: Option<u32>

Implementations

Source

impl Ext4DaReleaseSpaceFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn i_blocks(&self) -> u64

Returns the value of i_blocks, or the default value if i_blocks is unset.

pub fn freed_blocks(&self) -> i32

Returns the value of freed_blocks, or the default value if freed_blocks is unset.

pub fn reserved_data_blocks(&self) -> i32

Returns the value of reserved_data_blocks, or the default value if reserved_data_blocks is unset.

pub fn reserved_meta_blocks(&self) -> i32

Returns the value of reserved_meta_blocks, or the default value if reserved_meta_blocks is unset.

pub fn allocated_meta_blocks(&self) -> i32

Returns the value of allocated_meta_blocks, or the default value if allocated_meta_blocks is unset.

pub fn mode(&self) -> u32

Returns the value of mode, or the default value if mode is unset.