Ext4ExtRemoveSpaceDoneFtraceEvent

Struct Ext4ExtRemoveSpaceDoneFtraceEvent 

pub struct Ext4ExtRemoveSpaceDoneFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub start: Option<u32>,
    pub end: Option<u32>,
    pub depth: Option<i32>,
    pub partial: Option<i64>,
    pub eh_entries: Option<u32>,
    pub pc_lblk: Option<u32>,
    pub pc_pclu: Option<u64>,
    pub pc_state: Option<i32>,
}

Fields

dev: Option<u64>ino: Option<u64>start: Option<u32>end: Option<u32>depth: Option<i32>partial: Option<i64>eh_entries: Option<u32>pc_lblk: Option<u32>pc_pclu: Option<u64>pc_state: Option<i32>

Implementations

Source

impl Ext4ExtRemoveSpaceDoneFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn start(&self) -> u32

Returns the value of start, or the default value if start is unset.

pub fn end(&self) -> u32

Returns the value of end, or the default value if end is unset.

pub fn depth(&self) -> i32

Returns the value of depth, or the default value if depth is unset.

pub fn partial(&self) -> i64

Returns the value of partial, or the default value if partial is unset.

pub fn eh_entries(&self) -> u32

Returns the value of eh_entries, or the default value if eh_entries is unset.

pub fn pc_lblk(&self) -> u32

Returns the value of pc_lblk, or the default value if pc_lblk is unset.

pub fn pc_pclu(&self) -> u64

Returns the value of pc_pclu, or the default value if pc_pclu is unset.

pub fn pc_state(&self) -> i32

Returns the value of pc_state, or the default value if pc_state is unset.