Ext4FindDelallocRangeFtraceEvent

Struct Ext4FindDelallocRangeFtraceEvent 

pub struct Ext4FindDelallocRangeFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub from: Option<u32>,
    pub to: Option<u32>,
    pub reverse: Option<i32>,
    pub found: Option<i32>,
    pub found_blk: Option<u32>,
}

Fields

dev: Option<u64>ino: Option<u64>from: Option<u32>to: Option<u32>reverse: Option<i32>found: Option<i32>found_blk: Option<u32>

Implementations

Source

impl Ext4FindDelallocRangeFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn from(&self) -> u32

Returns the value of from, or the default value if from is unset.

pub fn to(&self) -> u32

Returns the value of to, or the default value if to is unset.

pub fn reverse(&self) -> i32

Returns the value of reverse, or the default value if reverse is unset.

pub fn found(&self) -> i32

Returns the value of found, or the default value if found is unset.

pub fn found_blk(&self) -> u32

Returns the value of found_blk, or the default value if found_blk is unset.