Ext4RemoveBlocksFtraceEvent

Struct Ext4RemoveBlocksFtraceEvent 

pub struct Ext4RemoveBlocksFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub from: Option<u32>,
    pub to: Option<u32>,
    pub partial: Option<i64>,
    pub ee_pblk: Option<u64>,
    pub ee_lblk: Option<u32>,
    pub ee_len: Option<u32>,
    pub pc_lblk: Option<u32>,
    pub pc_pclu: Option<u64>,
    pub pc_state: Option<i32>,
}

Fields

dev: Option<u64>ino: Option<u64>from: Option<u32>to: Option<u32>partial: Option<i64>ee_pblk: Option<u64>ee_lblk: Option<u32>ee_len: Option<u32>pc_lblk: Option<u32>pc_pclu: Option<u64>pc_state: Option<i32>

Implementations

Source

impl Ext4RemoveBlocksFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn from(&self) -> u32

Returns the value of from, or the default value if from is unset.

pub fn to(&self) -> u32

Returns the value of to, or the default value if to is unset.

pub fn partial(&self) -> i64

Returns the value of partial, or the default value if partial is unset.

pub fn ee_pblk(&self) -> u64

Returns the value of ee_pblk, or the default value if ee_pblk is unset.

pub fn ee_lblk(&self) -> u32

Returns the value of ee_lblk, or the default value if ee_lblk is unset.

pub fn ee_len(&self) -> u32

Returns the value of ee_len, or the default value if ee_len is unset.

pub fn pc_lblk(&self) -> u32

Returns the value of pc_lblk, or the default value if pc_lblk is unset.

pub fn pc_pclu(&self) -> u64

Returns the value of pc_pclu, or the default value if pc_pclu is unset.

pub fn pc_state(&self) -> i32

Returns the value of pc_state, or the default value if pc_state is unset.