F2fsGcEndFtraceEvent

Struct F2fsGcEndFtraceEvent 

pub struct F2fsGcEndFtraceEvent {
    pub dev: Option<u64>,
    pub ret: Option<i32>,
    pub seg_freed: Option<i32>,
    pub sec_freed: Option<i32>,
    pub dirty_nodes: Option<i64>,
    pub dirty_dents: Option<i64>,
    pub dirty_imeta: Option<i64>,
    pub free_sec: Option<u32>,
    pub free_seg: Option<u32>,
    pub reserved_seg: Option<i32>,
    pub prefree_seg: Option<u32>,
}

Fields

dev: Option<u64>ret: Option<i32>seg_freed: Option<i32>sec_freed: Option<i32>dirty_nodes: Option<i64>dirty_dents: Option<i64>dirty_imeta: Option<i64>free_sec: Option<u32>free_seg: Option<u32>reserved_seg: Option<i32>prefree_seg: Option<u32>

Implementations

Source

impl F2fsGcEndFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.

pub fn seg_freed(&self) -> i32

Returns the value of seg_freed, or the default value if seg_freed is unset.

pub fn sec_freed(&self) -> i32

Returns the value of sec_freed, or the default value if sec_freed is unset.

pub fn dirty_nodes(&self) -> i64

Returns the value of dirty_nodes, or the default value if dirty_nodes is unset.

pub fn dirty_dents(&self) -> i64

Returns the value of dirty_dents, or the default value if dirty_dents is unset.

pub fn dirty_imeta(&self) -> i64

Returns the value of dirty_imeta, or the default value if dirty_imeta is unset.

pub fn free_sec(&self) -> u32

Returns the value of free_sec, or the default value if free_sec is unset.

pub fn free_seg(&self) -> u32

Returns the value of free_seg, or the default value if free_seg is unset.

pub fn reserved_seg(&self) -> i32

Returns the value of reserved_seg, or the default value if reserved_seg is unset.

pub fn prefree_seg(&self) -> u32

Returns the value of prefree_seg, or the default value if prefree_seg is unset.