F2fsGetVictimFtraceEvent

Struct F2fsGetVictimFtraceEvent 

pub struct F2fsGetVictimFtraceEvent {
    pub dev: Option<u64>,
    pub type: Option<i32>,
    pub gc_type: Option<i32>,
    pub alloc_mode: Option<i32>,
    pub gc_mode: Option<i32>,
    pub victim: Option<u32>,
    pub ofs_unit: Option<u32>,
    pub pre_victim: Option<u32>,
    pub prefree: Option<u32>,
    pub free: Option<u32>,
    pub cost: Option<u32>,
}

Fields

dev: Option<u64>type: Option<i32>gc_type: Option<i32>alloc_mode: Option<i32>gc_mode: Option<i32>victim: Option<u32>ofs_unit: Option<u32>pre_victim: Option<u32>prefree: Option<u32>free: Option<u32>cost: Option<u32>

Implementations

Source

impl F2fsGetVictimFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn type(&self) -> i32

Returns the value of type, or the default value if type is unset.

pub fn gc_type(&self) -> i32

Returns the value of gc_type, or the default value if gc_type is unset.

pub fn alloc_mode(&self) -> i32

Returns the value of alloc_mode, or the default value if alloc_mode is unset.

pub fn gc_mode(&self) -> i32

Returns the value of gc_mode, or the default value if gc_mode is unset.

pub fn victim(&self) -> u32

Returns the value of victim, or the default value if victim is unset.

pub fn ofs_unit(&self) -> u32

Returns the value of ofs_unit, or the default value if ofs_unit is unset.

pub fn pre_victim(&self) -> u32

Returns the value of pre_victim, or the default value if pre_victim is unset.

pub fn prefree(&self) -> u32

Returns the value of prefree, or the default value if prefree is unset.

pub fn free(&self) -> u32

Returns the value of free, or the default value if free is unset.

pub fn cost(&self) -> u32

Returns the value of cost, or the default value if cost is unset.