F2fsLockElapsedTimeFtraceEvent

Struct F2fsLockElapsedTimeFtraceEvent 

pub struct F2fsLockElapsedTimeFtraceEvent {
Show 13 fields pub dev: Option<u64>, pub comm: Option<String>, pub pid: Option<i32>, pub prio: Option<i32>, pub ioprio_class: Option<i32>, pub ioprio_data: Option<i32>, pub lock_name: Option<u32>, pub is_write: Option<u32>, pub total_time: Option<u64>, pub running_time: Option<u64>, pub runnable_time: Option<u64>, pub io_sleep_time: Option<u64>, pub other_time: Option<u64>,
}

Fields

dev: Option<u64>comm: Option<String>pid: Option<i32>prio: Option<i32>ioprio_class: Option<i32>ioprio_data: Option<i32>lock_name: Option<u32>is_write: Option<u32>total_time: Option<u64>running_time: Option<u64>runnable_time: Option<u64>io_sleep_time: Option<u64>other_time: Option<u64>

Implementations

Source

impl F2fsLockElapsedTimeFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn prio(&self) -> i32

Returns the value of prio, or the default value if prio is unset.

pub fn ioprio_class(&self) -> i32

Returns the value of ioprio_class, or the default value if ioprio_class is unset.

pub fn ioprio_data(&self) -> i32

Returns the value of ioprio_data, or the default value if ioprio_data is unset.

pub fn lock_name(&self) -> u32

Returns the value of lock_name, or the default value if lock_name is unset.

pub fn is_write(&self) -> u32

Returns the value of is_write, or the default value if is_write is unset.

pub fn total_time(&self) -> u64

Returns the value of total_time, or the default value if total_time is unset.

pub fn running_time(&self) -> u64

Returns the value of running_time, or the default value if running_time is unset.

pub fn runnable_time(&self) -> u64

Returns the value of runnable_time, or the default value if runnable_time is unset.

pub fn io_sleep_time(&self) -> u64

Returns the value of io_sleep_time, or the default value if io_sleep_time is unset.

pub fn other_time(&self) -> u64

Returns the value of other_time, or the default value if other_time is unset.