F2fsReserveNewBlockFtraceEvent

Struct F2fsReserveNewBlockFtraceEvent 

pub struct F2fsReserveNewBlockFtraceEvent {
    pub dev: Option<u64>,
    pub nid: Option<u32>,
    pub ofs_in_node: Option<u32>,
}

Fields

dev: Option<u64>nid: Option<u32>ofs_in_node: Option<u32>

Implementations

Source

impl F2fsReserveNewBlockFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn nid(&self) -> u32

Returns the value of nid, or the default value if nid is unset.

pub fn ofs_in_node(&self) -> u32

Returns the value of ofs_in_node, or the default value if ofs_in_node is unset.