F2fsSyncFileExitFtraceEvent

Struct F2fsSyncFileExitFtraceEvent 

pub struct F2fsSyncFileExitFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub need_cp: Option<u32>,
    pub datasync: Option<i32>,
    pub ret: Option<i32>,
    pub cp_reason: Option<i32>,
}

Fields

dev: Option<u64>ino: Option<u64>need_cp: Option<u32>datasync: Option<i32>ret: Option<i32>cp_reason: Option<i32>

Implementations

Source

impl F2fsSyncFileExitFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn need_cp(&self) -> u32

Returns the value of need_cp, or the default value if need_cp is unset.

pub fn datasync(&self) -> i32

Returns the value of datasync, or the default value if datasync is unset.

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.

pub fn cp_reason(&self) -> i32

Returns the value of cp_reason, or the default value if cp_reason is unset.