F2fsTruncateBlocksExitFtraceEvent

Struct F2fsTruncateBlocksExitFtraceEvent 

pub struct F2fsTruncateBlocksExitFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub ret: Option<i32>,
}

Fields

dev: Option<u64>ino: Option<u64>ret: Option<i32>

Implementations

Source

impl F2fsTruncateBlocksExitFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.