F2fsTruncateNodesEnterFtraceEvent

Struct F2fsTruncateNodesEnterFtraceEvent 

pub struct F2fsTruncateNodesEnterFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub nid: Option<u32>,
    pub blk_addr: Option<u32>,
}

Fields

dev: Option<u64>ino: Option<u64>nid: Option<u32>blk_addr: Option<u32>

Implementations

Source

impl F2fsTruncateNodesEnterFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn nid(&self) -> u32

Returns the value of nid, or the default value if nid is unset.

pub fn blk_addr(&self) -> u32

Returns the value of blk_addr, or the default value if blk_addr is unset.