FastrpcDmaAllocFtraceEvent

Struct FastrpcDmaAllocFtraceEvent 

pub struct FastrpcDmaAllocFtraceEvent {
    pub cid: Option<i32>,
    pub phys: Option<u64>,
    pub size: Option<u64>,
    pub attr: Option<u64>,
    pub mflags: Option<i32>,
}

Fields

cid: Option<i32>phys: Option<u64>size: Option<u64>attr: Option<u64>mflags: Option<i32>

Implementations

Source

impl FastrpcDmaAllocFtraceEvent

pub fn cid(&self) -> i32

Returns the value of cid, or the default value if cid is unset.

pub fn phys(&self) -> u64

Returns the value of phys, or the default value if phys is unset.

pub fn size(&self) -> u64

Returns the value of size, or the default value if size is unset.

pub fn attr(&self) -> u64

Returns the value of attr, or the default value if attr is unset.

pub fn mflags(&self) -> i32

Returns the value of mflags, or the default value if mflags is unset.