FileIoDirEnumEtwEvent

Struct FileIoDirEnumEtwEvent 

pub struct FileIoDirEnumEtwEvent {
    pub irp_ptr: Option<u64>,
    pub file_object: Option<u64>,
    pub file_key: Option<u64>,
    pub ttid: Option<u32>,
    pub length: Option<u32>,
    pub info_class: Option<u32>,
    pub file_index: Option<u32>,
    pub file_name: Option<String>,
    pub opcode: Option<u32>,
}
Proto definition based on the FileIo_DirEnum class definition.

Fields

irp_ptr: Option<u64>file_object: Option<u64>file_key: Option<u64>ttid: Option<u32>length: Option<u32>info_class: Option<u32>file_index: Option<u32>file_name: Option<String>opcode: Option<u32>

Implementations

Source

impl FileIoDirEnumEtwEvent

pub fn irp_ptr(&self) -> u64

Returns the value of irp_ptr, or the default value if irp_ptr is unset.

pub fn file_object(&self) -> u64

Returns the value of file_object, or the default value if file_object is unset.

pub fn file_key(&self) -> u64

Returns the value of file_key, or the default value if file_key is unset.

pub fn ttid(&self) -> u32

Returns the value of ttid, or the default value if ttid is unset.

pub fn length(&self) -> u32

Returns the value of length, or the default value if length is unset.

pub fn info_class(&self) -> u32

Returns the value of info_class, or the default value if info_class is unset.

pub fn file_index(&self) -> u32

Returns the value of file_index, or the default value if file_index is unset.

pub fn file_name(&self) -> &str

Returns the value of file_name, or the default value if file_name is unset.

pub fn opcode(&self) -> u32

Returns the value of opcode, or the default value if opcode is unset.