FtraceKprobeStats

Struct FtraceKprobeStats 

pub struct FtraceKprobeStats {
    pub hits: Option<i64>,
    pub misses: Option<i64>,
}
Kprobe statistical data, gathered from /sys/kernel/tracing/kprobe_profile.

Fields

hits: Option<i64>

Cumulative number of kprobe events generated for this function

misses: Option<i64>

Cumulative number of kprobe events that could not be generated for this function and were missed. This happens when too much nesting happens between a kprobe and its kretprobe, overflowing the maxactives buffer.

Implementations

Source

impl FtraceKprobeStats

pub fn hits(&self) -> i64

Returns the value of hits, or the default value if hits is unset.

pub fn misses(&self) -> i64

Returns the value of misses, or the default value if misses is unset.