pub struct GpuCounterEvent {
pub counters: Vec<GpuCounter>,
pub gpu_id: Option<i32>,
pub desc: Option<Desc>,
}Expand description
Events for emitting information about GPU counters.
There are two “modes” to use these protos:
- Using GpuCounterDescriptor. This is the simplest way to use this proto but has the limitation that counter ids areglobal so must only be emitted by a single producer or requires coordination between different producers. This is the mechanism which must be used by Android OEMS to be complaint with CDD/CTS tests.
- Using InternedGpuCounterDescriptor. This is generally recommended for more complex use-cases involving multiple producers, multiple GPUs etc.
Fields
counters: Vec<GpuCounter>gpu_id: Option<i32>Identifier for GPU in a multi-gpu device.
If counter_descriptor_iid is specified, the gpu_id in
InternedGpuCounterDescriptor takes precedence over this field.
desc: Option<Desc>The specification for the GPU counters. Gives them information like the name of the counter, unit etc.
Implementations