GpuLog

Struct GpuLog 

pub struct GpuLog {
    pub severity: Option<i32>,
    pub tag: Option<String>,
    pub log_message: Option<String>,
}
Message for logging events GPU data producer.

Fields

severity: Option<i32>tag: Option<String>log_message: Option<String>

Implementations

Source

impl GpuLog

pub fn severity(&self) -> Severity

Returns the enum value of severity, or the default if the field is unset or set to an invalid enum value.

pub fn set_severity(&mut self, value: Severity)

Sets severity to the provided enum value.

pub fn tag(&self) -> &str

Returns the value of tag, or the default value if tag is unset.

pub fn log_message(&self) -> &str

Returns the value of log_message, or the default value if log_message is unset.