pub struct HeapGraphObject {Show 13 fields
pub type_id: Option<u64>,
pub self_size: Option<u64>,
pub reference_field_id_base: Option<u64>,
pub reference_field_id: Vec<u64>,
pub reference_object_id: Vec<u64>,
pub heap_type_delta: Option<i32>,
pub runtime_internal_object_id: Vec<u64>,
pub native_allocation_registry_size_field: Option<i64>,
pub bitmap_id_field: Option<i64>,
pub bitmap_source_id_field: Option<i64>,
pub bitmap_width_field: Option<u32>,
pub bitmap_height_field: Option<u32>,
pub identifier: Option<Identifier>,
}Fields
type_id: Option<u64>Index for InternedData.types for the name of the type of this object.
self_size: Option<u64>Bytes occupied by this objects.
reference_field_id_base: Option<u64>Add this to all non-zero values in reference_object_id. This is used to get more compact varint encoding.
The name is confusing, but this has always been used as a base for reference_object_id. The field should be named reference_object_id_base.
reference_field_id: Vec<u64>Indices for InternedData.field_names for the name of the field referring to the object. For Android S+ and for instances of normal classes (e.g. not instances of java.lang.Class or arrays), this is instead set in the corresponding HeapGraphType, and this is left empty.
reference_object_id: Vec<u64>Ids of the Object that is referred to.
heap_type_delta: Option<i32>To reduce the space required we only emit the heap type if it has changed from the previous object we recorded.
runtime_internal_object_id: Vec<u64>Ids of the Objects referred by this object, not via fields, but via internal runtime structures.
native_allocation_registry_size_field: Option<i64>libcore.util.NativeAllocationRegistry.size: Maps to the size (bytes) of
the corresponding objects registered with the native allocation registry.
N.B. this can be an approximation.
bitmap_id_field: Option<i64>Bitmap-specific field captures, only applicable to objects of this type.
android.graphics.Bitmap.mId: Used for storage type and deduplication.
bitmap_source_id_field: Option<i64>android.graphics.Bitmap.mSourceId: Used to identify the source process.
bitmap_width_field: Option<u32>android.graphics.Bitmap.mWidth: Width in pixels
bitmap_height_field: Option<u32>android.graphics.Bitmap.mHeight: Height in pixels
identifier: Option<Identifier>Implementations
Sourceimpl HeapGraphObject
impl HeapGraphObject
Sourcepub fn type_id(&self) -> u64
pub fn type_id(&self) -> u64
Returns the value of type_id, or the default value if type_id is unset.
Sourcepub fn self_size(&self) -> u64
pub fn self_size(&self) -> u64
Returns the value of self_size, or the default value if self_size is unset.
Sourcepub fn reference_field_id_base(&self) -> u64
pub fn reference_field_id_base(&self) -> u64
Returns the value of reference_field_id_base, or the default value if reference_field_id_base is unset.
Sourcepub fn native_allocation_registry_size_field(&self) -> i64
pub fn native_allocation_registry_size_field(&self) -> i64
Returns the value of native_allocation_registry_size_field, or the default value if native_allocation_registry_size_field is unset.
Sourcepub fn heap_type_delta(&self) -> HeapType
pub fn heap_type_delta(&self) -> HeapType
Returns the enum value of heap_type_delta, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_heap_type_delta(&mut self, value: HeapType)
pub fn set_heap_type_delta(&mut self, value: HeapType)
Sets heap_type_delta to the provided enum value.
Sourcepub fn bitmap_id_field(&self) -> i64
pub fn bitmap_id_field(&self) -> i64
Returns the value of bitmap_id_field, or the default value if bitmap_id_field is unset.
Sourcepub fn bitmap_source_id_field(&self) -> i64
pub fn bitmap_source_id_field(&self) -> i64
Returns the value of bitmap_source_id_field, or the default value if bitmap_source_id_field is unset.
Sourcepub fn bitmap_width_field(&self) -> u32
pub fn bitmap_width_field(&self) -> u32
Returns the value of bitmap_width_field, or the default value if bitmap_width_field is unset.
Sourcepub fn bitmap_height_field(&self) -> u32
pub fn bitmap_height_field(&self) -> u32
Returns the value of bitmap_height_field, or the default value if bitmap_height_field is unset.