HrtimerExpireEntryFtraceEvent

Struct HrtimerExpireEntryFtraceEvent 

pub struct HrtimerExpireEntryFtraceEvent {
    pub hrtimer: Option<u64>,
    pub now: Option<i64>,
    pub function: Option<u64>,
}

Fields

hrtimer: Option<u64>now: Option<i64>function: Option<u64>

Implementations

Source

impl HrtimerExpireEntryFtraceEvent

pub fn hrtimer(&self) -> u64

Returns the value of hrtimer, or the default value if hrtimer is unset.

pub fn now(&self) -> i64

Returns the value of now, or the default value if now is unset.

pub fn function(&self) -> u64

Returns the value of function, or the default value if function is unset.