HrtimerStartFtraceEvent

Struct HrtimerStartFtraceEvent 

pub struct HrtimerStartFtraceEvent {
    pub hrtimer: Option<u64>,
    pub function: Option<u64>,
    pub expires: Option<i64>,
    pub softexpires: Option<i64>,
    pub mode: Option<u32>,
}

Fields

hrtimer: Option<u64>function: Option<u64>expires: Option<i64>softexpires: Option<i64>mode: Option<u32>

Implementations

Source

impl HrtimerStartFtraceEvent

pub fn hrtimer(&self) -> u64

Returns the value of hrtimer, or the default value if hrtimer is unset.

pub fn function(&self) -> u64

Returns the value of function, or the default value if function is unset.

pub fn expires(&self) -> i64

Returns the value of expires, or the default value if expires is unset.

pub fn softexpires(&self) -> i64

Returns the value of softexpires, or the default value if softexpires is unset.

pub fn mode(&self) -> u32

Returns the value of mode, or the default value if mode is unset.