I2cWriteFtraceEvent

Struct I2cWriteFtraceEvent 

pub struct I2cWriteFtraceEvent {
    pub adapter_nr: Option<i32>,
    pub msg_nr: Option<u32>,
    pub addr: Option<u32>,
    pub flags: Option<u32>,
    pub len: Option<u32>,
    pub buf: Option<Vec<u8>>,
}

Fields

adapter_nr: Option<i32>msg_nr: Option<u32>addr: Option<u32>flags: Option<u32>len: Option<u32>buf: Option<Vec<u8>>

Implementations

Source

impl I2cWriteFtraceEvent

pub fn adapter_nr(&self) -> i32

Returns the value of adapter_nr, or the default value if adapter_nr is unset.

pub fn msg_nr(&self) -> u32

Returns the value of msg_nr, or the default value if msg_nr is unset.

pub fn addr(&self) -> u32

Returns the value of addr, or the default value if addr is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn len(&self) -> u32

Returns the value of len, or the default value if len is unset.

pub fn buf(&self) -> &[u8]

Returns the value of buf, or the default value if buf is unset.