InetSockSetStateFtraceEvent

Struct InetSockSetStateFtraceEvent 

pub struct InetSockSetStateFtraceEvent {
    pub daddr: Option<u32>,
    pub dport: Option<u32>,
    pub family: Option<u32>,
    pub newstate: Option<i32>,
    pub oldstate: Option<i32>,
    pub protocol: Option<u32>,
    pub saddr: Option<u32>,
    pub skaddr: Option<u64>,
    pub sport: Option<u32>,
}

Fields

daddr: Option<u32>dport: Option<u32>family: Option<u32>newstate: Option<i32>oldstate: Option<i32>protocol: Option<u32>saddr: Option<u32>skaddr: Option<u64>sport: Option<u32>

Implementations

Source

impl InetSockSetStateFtraceEvent

pub fn daddr(&self) -> u32

Returns the value of daddr, or the default value if daddr is unset.

pub fn dport(&self) -> u32

Returns the value of dport, or the default value if dport is unset.

pub fn family(&self) -> u32

Returns the value of family, or the default value if family is unset.

pub fn newstate(&self) -> i32

Returns the value of newstate, or the default value if newstate is unset.

pub fn oldstate(&self) -> i32

Returns the value of oldstate, or the default value if oldstate is unset.

pub fn protocol(&self) -> u32

Returns the value of protocol, or the default value if protocol is unset.

pub fn saddr(&self) -> u32

Returns the value of saddr, or the default value if saddr is unset.

pub fn skaddr(&self) -> u64

Returns the value of skaddr, or the default value if skaddr is unset.

pub fn sport(&self) -> u32

Returns the value of sport, or the default value if sport is unset.