InternedV8JsFunction

Struct InternedV8JsFunction 

pub struct InternedV8JsFunction {
    pub iid: Option<u64>,
    pub v8_js_function_name_iid: Option<u64>,
    pub v8_js_script_iid: Option<u64>,
    pub is_toplevel: Option<bool>,
    pub kind: Option<i32>,
    pub byte_offset: Option<u32>,
    pub line: Option<u32>,
    pub column: Option<u32>,
}

Fields

iid: Option<u64>v8_js_function_name_iid: Option<u64>v8_js_script_iid: Option<u64>is_toplevel: Option<bool>kind: Option<i32>byte_offset: Option<u32>

Where in the script source this function is defined. This is counted in bytes not characters.

line: Option<u32>column: Option<u32>

Implementations

Source

impl InternedV8JsFunction

pub fn iid(&self) -> u64

Returns the value of iid, or the default value if iid is unset.

pub fn v8_js_function_name_iid(&self) -> u64

Returns the value of v8_js_function_name_iid, or the default value if v8_js_function_name_iid is unset.

pub fn v8_js_script_iid(&self) -> u64

Returns the value of v8_js_script_iid, or the default value if v8_js_script_iid is unset.

pub fn is_toplevel(&self) -> bool

Returns the value of is_toplevel, or the default value if is_toplevel is unset.

pub fn kind(&self) -> Kind

Returns the enum value of kind, or the default if the field is unset or set to an invalid enum value.

pub fn set_kind(&mut self, value: Kind)

Sets kind to the provided enum value.

pub fn byte_offset(&self) -> u32

Returns the value of byte_offset, or the default value if byte_offset is unset.

pub fn line(&self) -> u32

Returns the value of line, or the default value if line is unset.

pub fn column(&self) -> u32

Returns the value of column, or the default value if column is unset.