InternedV8JsScript

Struct InternedV8JsScript 

pub struct InternedV8JsScript {
    pub iid: Option<u64>,
    pub script_id: Option<i32>,
    pub type: Option<i32>,
    pub name: Option<V8String>,
    pub source: Option<V8String>,
}
Represents a script that was compiled to generate code. Some V8 code is generated out of scripts and will reference a V8Script other types of code will not (e.g. builtins).

Fields

iid: Option<u64>script_id: Option<i32>

Unique in a given isolate

type: Option<i32>name: Option<V8String>source: Option<V8String>

Actual source of the script

Implementations

Source

impl InternedV8JsScript

pub fn iid(&self) -> u64

Returns the value of iid, or the default value if iid is unset.

pub fn script_id(&self) -> i32

Returns the value of script_id, or the default value if script_id is unset.

pub fn type(&self) -> Type

Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.

pub fn set_type(&mut self, value: Type)

Sets type to the provided enum value.