IommuIdmapFtraceEvent

Struct IommuIdmapFtraceEvent 

pub struct IommuIdmapFtraceEvent {
    pub from: Option<u64>,
    pub to: Option<u64>,
    pub prot: Option<i32>,
}

Fields

from: Option<u64>to: Option<u64>prot: Option<i32>

Implementations

Source

impl IommuIdmapFtraceEvent

pub fn from(&self) -> u64

Returns the value of from, or the default value if from is unset.

pub fn to(&self) -> u64

Returns the value of to, or the default value if to is unset.

pub fn prot(&self) -> i32

Returns the value of prot, or the default value if prot is unset.