KgslAdrenoCmdbatchRetiredFtraceEvent

Struct KgslAdrenoCmdbatchRetiredFtraceEvent 

pub struct KgslAdrenoCmdbatchRetiredFtraceEvent {
Show 17 fields pub id: Option<u32>, pub timestamp: Option<u32>, pub inflight: Option<i64>, pub recovery: Option<u32>, pub flags: Option<u32>, pub start: Option<u64>, pub retire: Option<u64>, pub prio: Option<i32>, pub rb_id: Option<i32>, pub rptr: Option<u32>, pub wptr: Option<u32>, pub q_inflight: Option<i32>, pub fault_recovery: Option<u64>, pub dispatch_queue: Option<u32>, pub submitted_to_rb: Option<u64>, pub retired_on_gmu: Option<u64>, pub active: Option<u64>,
}

Fields

id: Option<u32>timestamp: Option<u32>inflight: Option<i64>recovery: Option<u32>flags: Option<u32>start: Option<u64>retire: Option<u64>prio: Option<i32>rb_id: Option<i32>rptr: Option<u32>wptr: Option<u32>q_inflight: Option<i32>fault_recovery: Option<u64>dispatch_queue: Option<u32>submitted_to_rb: Option<u64>retired_on_gmu: Option<u64>active: Option<u64>

Implementations

Source

impl KgslAdrenoCmdbatchRetiredFtraceEvent

pub fn id(&self) -> u32

Returns the value of id, or the default value if id is unset.

pub fn timestamp(&self) -> u32

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn inflight(&self) -> i64

Returns the value of inflight, or the default value if inflight is unset.

pub fn recovery(&self) -> u32

Returns the value of recovery, or the default value if recovery is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn start(&self) -> u64

Returns the value of start, or the default value if start is unset.

pub fn retire(&self) -> u64

Returns the value of retire, or the default value if retire is unset.

pub fn prio(&self) -> i32

Returns the value of prio, or the default value if prio is unset.

pub fn rb_id(&self) -> i32

Returns the value of rb_id, or the default value if rb_id is unset.

pub fn rptr(&self) -> u32

Returns the value of rptr, or the default value if rptr is unset.

pub fn wptr(&self) -> u32

Returns the value of wptr, or the default value if wptr is unset.

pub fn q_inflight(&self) -> i32

Returns the value of q_inflight, or the default value if q_inflight is unset.

pub fn fault_recovery(&self) -> u64

Returns the value of fault_recovery, or the default value if fault_recovery is unset.

pub fn dispatch_queue(&self) -> u32

Returns the value of dispatch_queue, or the default value if dispatch_queue is unset.

pub fn submitted_to_rb(&self) -> u64

Returns the value of submitted_to_rb, or the default value if submitted_to_rb is unset.

pub fn retired_on_gmu(&self) -> u64

Returns the value of retired_on_gmu, or the default value if retired_on_gmu is unset.

pub fn active(&self) -> u64

Returns the value of active, or the default value if active is unset.