KgslAdrenoCmdbatchSubmittedFtraceEvent

Struct KgslAdrenoCmdbatchSubmittedFtraceEvent 

pub struct KgslAdrenoCmdbatchSubmittedFtraceEvent {
Show 13 fields pub id: Option<u32>, pub timestamp: Option<u32>, pub inflight: Option<i64>, pub flags: Option<u32>, pub ticks: Option<u64>, pub secs: Option<u64>, pub usecs: Option<u64>, pub prio: Option<i32>, pub rb_id: Option<i32>, pub rptr: Option<u32>, pub wptr: Option<u32>, pub q_inflight: Option<i32>, pub dispatch_queue: Option<i32>,
}

Fields

id: Option<u32>timestamp: Option<u32>inflight: Option<i64>flags: Option<u32>ticks: Option<u64>secs: Option<u64>usecs: Option<u64>prio: Option<i32>rb_id: Option<i32>rptr: Option<u32>wptr: Option<u32>q_inflight: Option<i32>dispatch_queue: Option<i32>

Implementations

Source

impl KgslAdrenoCmdbatchSubmittedFtraceEvent

pub fn id(&self) -> u32

Returns the value of id, or the default value if id is unset.

pub fn timestamp(&self) -> u32

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn inflight(&self) -> i64

Returns the value of inflight, or the default value if inflight is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn ticks(&self) -> u64

Returns the value of ticks, or the default value if ticks is unset.

pub fn secs(&self) -> u64

Returns the value of secs, or the default value if secs is unset.

pub fn usecs(&self) -> u64

Returns the value of usecs, or the default value if usecs is unset.

pub fn prio(&self) -> i32

Returns the value of prio, or the default value if prio is unset.

pub fn rb_id(&self) -> i32

Returns the value of rb_id, or the default value if rb_id is unset.

pub fn rptr(&self) -> u32

Returns the value of rptr, or the default value if rptr is unset.

pub fn wptr(&self) -> u32

Returns the value of wptr, or the default value if wptr is unset.

pub fn q_inflight(&self) -> i32

Returns the value of q_inflight, or the default value if q_inflight is unset.

pub fn dispatch_queue(&self) -> i32

Returns the value of dispatch_queue, or the default value if dispatch_queue is unset.