KvmTimerRestoreStateFtraceEvent

Struct KvmTimerRestoreStateFtraceEvent 

pub struct KvmTimerRestoreStateFtraceEvent {
    pub ctl: Option<u64>,
    pub cval: Option<u64>,
    pub timer_idx: Option<i32>,
}

Fields

ctl: Option<u64>cval: Option<u64>timer_idx: Option<i32>

Implementations

Source

impl KvmTimerRestoreStateFtraceEvent

pub fn ctl(&self) -> u64

Returns the value of ctl, or the default value if ctl is unset.

pub fn cval(&self) -> u64

Returns the value of cval, or the default value if cval is unset.

pub fn timer_idx(&self) -> i32

Returns the value of timer_idx, or the default value if timer_idx is unset.