KvmUnmapHvaRangeFtraceEvent

Struct KvmUnmapHvaRangeFtraceEvent 

pub struct KvmUnmapHvaRangeFtraceEvent {
    pub end: Option<u64>,
    pub start: Option<u64>,
}

Fields

end: Option<u64>start: Option<u64>

Implementations

Source

impl KvmUnmapHvaRangeFtraceEvent

pub fn end(&self) -> u64

Returns the value of end, or the default value if end is unset.

pub fn start(&self) -> u64

Returns the value of start, or the default value if start is unset.