MdpPerfPrefillCalcFtraceEvent

Struct MdpPerfPrefillCalcFtraceEvent 

pub struct MdpPerfPrefillCalcFtraceEvent {
    pub pnum: Option<u32>,
    pub latency_buf: Option<u32>,
    pub ot: Option<u32>,
    pub y_buf: Option<u32>,
    pub y_scaler: Option<u32>,
    pub pp_lines: Option<u32>,
    pub pp_bytes: Option<u32>,
    pub post_sc: Option<u32>,
    pub fbc_bytes: Option<u32>,
    pub prefill_bytes: Option<u32>,
}

Fields

pnum: Option<u32>latency_buf: Option<u32>ot: Option<u32>y_buf: Option<u32>y_scaler: Option<u32>pp_lines: Option<u32>pp_bytes: Option<u32>post_sc: Option<u32>fbc_bytes: Option<u32>prefill_bytes: Option<u32>

Implementations

Source

impl MdpPerfPrefillCalcFtraceEvent

pub fn pnum(&self) -> u32

Returns the value of pnum, or the default value if pnum is unset.

pub fn latency_buf(&self) -> u32

Returns the value of latency_buf, or the default value if latency_buf is unset.

pub fn ot(&self) -> u32

Returns the value of ot, or the default value if ot is unset.

pub fn y_buf(&self) -> u32

Returns the value of y_buf, or the default value if y_buf is unset.

pub fn y_scaler(&self) -> u32

Returns the value of y_scaler, or the default value if y_scaler is unset.

pub fn pp_lines(&self) -> u32

Returns the value of pp_lines, or the default value if pp_lines is unset.

pub fn pp_bytes(&self) -> u32

Returns the value of pp_bytes, or the default value if pp_bytes is unset.

pub fn post_sc(&self) -> u32

Returns the value of post_sc, or the default value if post_sc is unset.

pub fn fbc_bytes(&self) -> u32

Returns the value of fbc_bytes, or the default value if fbc_bytes is unset.

pub fn prefill_bytes(&self) -> u32

Returns the value of prefill_bytes, or the default value if prefill_bytes is unset.