MdpPerfSetPanicLutsFtraceEvent

Struct MdpPerfSetPanicLutsFtraceEvent 

pub struct MdpPerfSetPanicLutsFtraceEvent {
    pub pnum: Option<u32>,
    pub fmt: Option<u32>,
    pub mode: Option<u32>,
    pub panic_lut: Option<u32>,
    pub robust_lut: Option<u32>,
}

Fields

pnum: Option<u32>fmt: Option<u32>mode: Option<u32>panic_lut: Option<u32>robust_lut: Option<u32>

Implementations

Source

impl MdpPerfSetPanicLutsFtraceEvent

pub fn pnum(&self) -> u32

Returns the value of pnum, or the default value if pnum is unset.

pub fn fmt(&self) -> u32

Returns the value of fmt, or the default value if fmt is unset.

pub fn mode(&self) -> u32

Returns the value of mode, or the default value if mode is unset.

pub fn panic_lut(&self) -> u32

Returns the value of panic_lut, or the default value if panic_lut is unset.

pub fn robust_lut(&self) -> u32

Returns the value of robust_lut, or the default value if robust_lut is unset.