MdpSsppChangeFtraceEvent

Struct MdpSsppChangeFtraceEvent 

pub struct MdpSsppChangeFtraceEvent {
Show 16 fields pub num: Option<u32>, pub play_cnt: Option<u32>, pub mixer: Option<u32>, pub stage: Option<u32>, pub flags: Option<u32>, pub format: Option<u32>, pub img_w: Option<u32>, pub img_h: Option<u32>, pub src_x: Option<u32>, pub src_y: Option<u32>, pub src_w: Option<u32>, pub src_h: Option<u32>, pub dst_x: Option<u32>, pub dst_y: Option<u32>, pub dst_w: Option<u32>, pub dst_h: Option<u32>,
}

Fields

num: Option<u32>play_cnt: Option<u32>mixer: Option<u32>stage: Option<u32>flags: Option<u32>format: Option<u32>img_w: Option<u32>img_h: Option<u32>src_x: Option<u32>src_y: Option<u32>src_w: Option<u32>src_h: Option<u32>dst_x: Option<u32>dst_y: Option<u32>dst_w: Option<u32>dst_h: Option<u32>

Implementations

Source

impl MdpSsppChangeFtraceEvent

pub fn num(&self) -> u32

Returns the value of num, or the default value if num is unset.

pub fn play_cnt(&self) -> u32

Returns the value of play_cnt, or the default value if play_cnt is unset.

pub fn mixer(&self) -> u32

Returns the value of mixer, or the default value if mixer is unset.

pub fn stage(&self) -> u32

Returns the value of stage, or the default value if stage is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn format(&self) -> u32

Returns the value of format, or the default value if format is unset.

pub fn img_w(&self) -> u32

Returns the value of img_w, or the default value if img_w is unset.

pub fn img_h(&self) -> u32

Returns the value of img_h, or the default value if img_h is unset.

pub fn src_x(&self) -> u32

Returns the value of src_x, or the default value if src_x is unset.

pub fn src_y(&self) -> u32

Returns the value of src_y, or the default value if src_y is unset.

pub fn src_w(&self) -> u32

Returns the value of src_w, or the default value if src_w is unset.

pub fn src_h(&self) -> u32

Returns the value of src_h, or the default value if src_h is unset.

pub fn dst_x(&self) -> u32

Returns the value of dst_x, or the default value if dst_x is unset.

pub fn dst_y(&self) -> u32

Returns the value of dst_y, or the default value if dst_y is unset.

pub fn dst_w(&self) -> u32

Returns the value of dst_w, or the default value if dst_w is unset.

pub fn dst_h(&self) -> u32

Returns the value of dst_h, or the default value if dst_h is unset.