MmCompactionDeferResetFtraceEvent

Struct MmCompactionDeferResetFtraceEvent 

pub struct MmCompactionDeferResetFtraceEvent {
    pub nid: Option<i32>,
    pub idx: Option<u32>,
    pub order: Option<i32>,
    pub considered: Option<u32>,
    pub defer_shift: Option<u32>,
    pub order_failed: Option<i32>,
}

Fields

nid: Option<i32>idx: Option<u32>order: Option<i32>considered: Option<u32>defer_shift: Option<u32>order_failed: Option<i32>

Implementations

Source

impl MmCompactionDeferResetFtraceEvent

pub fn nid(&self) -> i32

Returns the value of nid, or the default value if nid is unset.

pub fn idx(&self) -> u32

Returns the value of idx, or the default value if idx is unset.

pub fn order(&self) -> i32

Returns the value of order, or the default value if order is unset.

pub fn considered(&self) -> u32

Returns the value of considered, or the default value if considered is unset.

pub fn defer_shift(&self) -> u32

Returns the value of defer_shift, or the default value if defer_shift is unset.

pub fn order_failed(&self) -> i32

Returns the value of order_failed, or the default value if order_failed is unset.