MmEventRecordFtraceEvent

Struct MmEventRecordFtraceEvent 

pub struct MmEventRecordFtraceEvent {
    pub avg_lat: Option<u32>,
    pub count: Option<u32>,
    pub max_lat: Option<u32>,
    pub type: Option<u32>,
}

Fields

avg_lat: Option<u32>count: Option<u32>max_lat: Option<u32>type: Option<u32>

Implementations

Source

impl MmEventRecordFtraceEvent

pub fn avg_lat(&self) -> u32

Returns the value of avg_lat, or the default value if avg_lat is unset.

pub fn count(&self) -> u32

Returns the value of count, or the default value if count is unset.

pub fn max_lat(&self) -> u32

Returns the value of max_lat, or the default value if max_lat is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.