MmFilemapDeleteFromPageCacheFtraceEvent

Struct MmFilemapDeleteFromPageCacheFtraceEvent 

pub struct MmFilemapDeleteFromPageCacheFtraceEvent {
    pub pfn: Option<u64>,
    pub i_ino: Option<u64>,
    pub index: Option<u64>,
    pub s_dev: Option<u64>,
    pub page: Option<u64>,
}

Fields

pfn: Option<u64>i_ino: Option<u64>index: Option<u64>s_dev: Option<u64>page: Option<u64>

Implementations

Source

impl MmFilemapDeleteFromPageCacheFtraceEvent

pub fn pfn(&self) -> u64

Returns the value of pfn, or the default value if pfn is unset.

pub fn i_ino(&self) -> u64

Returns the value of i_ino, or the default value if i_ino is unset.

pub fn index(&self) -> u64

Returns the value of index, or the default value if index is unset.

pub fn s_dev(&self) -> u64

Returns the value of s_dev, or the default value if s_dev is unset.

pub fn page(&self) -> u64

Returns the value of page, or the default value if page is unset.