MmPageFreeBatchedFtraceEvent

Struct MmPageFreeBatchedFtraceEvent 

pub struct MmPageFreeBatchedFtraceEvent {
    pub cold: Option<i32>,
    pub page: Option<u64>,
    pub pfn: Option<u64>,
}

Fields

cold: Option<i32>page: Option<u64>pfn: Option<u64>

Implementations

Source

impl MmPageFreeBatchedFtraceEvent

pub fn cold(&self) -> i32

Returns the value of cold, or the default value if cold is unset.

pub fn page(&self) -> u64

Returns the value of page, or the default value if page is unset.

pub fn pfn(&self) -> u64

Returns the value of pfn, or the default value if pfn is unset.