pub struct PackagesListConfig {
pub package_name_filter: Vec<String>,
pub package_name_regex_filter: Vec<String>,
pub only_write_on_cpu_use_every_ms: Option<u32>,
}Expand description
Data source that lists details (such as version code) about packages on an Android device.
Fields
package_name_filter: Vec<String>If not empty, emit info about only the following list of package names (exact match, no regex). Can be combined with |package_name_regex_filter|: a package is included if it matches either filter. If both filters are empty, emit info about all packages.
package_name_regex_filter: Vec<String>If not empty, emit info about only the packages whose names match any of the following regexes (full match, not partial). Can be combined with |package_name_filter|: a package is included if it matches either filter. If both filters are empty, emit info about all packages. This field was introduced in Android 26Q2 (Perfetto v55).
only_write_on_cpu_use_every_ms: Option<u32>If present and non-zero, the data source will periodically poll for CPU use by packages and only emit results for those that it sees. If absent, the data source will emit results for all packages at startup. The package name filters apply either way.
Implementations
Sourceimpl PackagesListConfig
impl PackagesListConfig
Sourcepub fn only_write_on_cpu_use_every_ms(&self) -> u32
pub fn only_write_on_cpu_use_every_ms(&self) -> u32
Returns the value of only_write_on_cpu_use_every_ms, or the default value if only_write_on_cpu_use_every_ms is unset.