PackedSmaps

Struct PackedSmaps 

pub struct PackedSmaps {
Show 15 fields pub string_table: Vec<String>, pub name_id: Vec<u32>, pub aggregate_count: Vec<u32>, pub size_kb: Vec<u64>, pub rss_kb: Vec<u64>, pub anonymous_kb: Vec<u64>, pub swap_kb: Vec<u64>, pub shared_clean_kb: Vec<u64>, pub shared_dirty_kb: Vec<u64>, pub private_clean_kb: Vec<u64>, pub private_dirty_kb: Vec<u64>, pub locked_kb: Vec<u64>, pub pss_kb: Vec<u64>, pub pss_dirty_kb: Vec<u64>, pub swap_pss_kb: Vec<u64>,
}
Structure-of-arrays style smaps packet of a single process. All packed repeated fields, if set, must have the same length.

Fields

string_table: Vec<String>

Table of path names. Notes:

  • first element is the empty string, serialised explicitly.
  • the table might contain duplicates.
name_id: Vec<u32>

Interned file paths as an index into |string_table|. Note: the “(deleted)” suffix is kept as part of the string_table entry, and is to be handled during trace import stage. Written only if config.unaggregated == true. Otherwise the string_table is exactly the ordered names of the aggregated mappings.

aggregate_count: Vec<u32>

How many mappings were merged by name, summing the values below. Written only if config.unaggregated == false.

size_kb: Vec<u64>rss_kb: Vec<u64>anonymous_kb: Vec<u64>swap_kb: Vec<u64>shared_clean_kb: Vec<u64>shared_dirty_kb: Vec<u64>private_clean_kb: Vec<u64>private_dirty_kb: Vec<u64>locked_kb: Vec<u64>pss_kb: Vec<u64>pss_dirty_kb: Vec<u64>swap_pss_kb: Vec<u64>