PanelSettingsFullFtraceEvent

Struct PanelSettingsFullFtraceEvent 

pub struct PanelSettingsFullFtraceEvent {
    pub panel_index: Option<i32>,
    pub hbm: Option<u32>,
    pub irc: Option<u32>,
    pub h_pwm: Option<u32>,
    pub fi_auto: Option<u32>,
    pub fi_manual: Option<u32>,
    pub early_exit: Option<u32>,
    pub min_rr: Option<u32>,
    pub max_rr: Option<u32>,
    pub te_freq: Option<u32>,
}

Fields

panel_index: Option<i32>hbm: Option<u32>irc: Option<u32>h_pwm: Option<u32>fi_auto: Option<u32>fi_manual: Option<u32>early_exit: Option<u32>min_rr: Option<u32>max_rr: Option<u32>te_freq: Option<u32>

Implementations

Source

impl PanelSettingsFullFtraceEvent

pub fn panel_index(&self) -> i32

Returns the value of panel_index, or the default value if panel_index is unset.

pub fn hbm(&self) -> u32

Returns the value of hbm, or the default value if hbm is unset.

pub fn irc(&self) -> u32

Returns the value of irc, or the default value if irc is unset.

pub fn h_pwm(&self) -> u32

Returns the value of h_pwm, or the default value if h_pwm is unset.

pub fn fi_auto(&self) -> u32

Returns the value of fi_auto, or the default value if fi_auto is unset.

pub fn fi_manual(&self) -> u32

Returns the value of fi_manual, or the default value if fi_manual is unset.

pub fn early_exit(&self) -> u32

Returns the value of early_exit, or the default value if early_exit is unset.

pub fn min_rr(&self) -> u32

Returns the value of min_rr, or the default value if min_rr is unset.

pub fn max_rr(&self) -> u32

Returns the value of max_rr, or the default value if max_rr is unset.

pub fn te_freq(&self) -> u32

Returns the value of te_freq, or the default value if te_freq is unset.