PrintFtraceEvent

Struct PrintFtraceEvent 

pub struct PrintFtraceEvent {
    pub ip: Option<u64>,
    pub buf: Option<String>,
}

Fields

ip: Option<u64>buf: Option<String>

Implementations

Source

impl PrintFtraceEvent

pub fn ip(&self) -> u64

Returns the value of ip, or the default value if ip is unset.

pub fn buf(&self) -> &str

Returns the value of buf, or the default value if buf is unset.