PsciMemProtectFtraceEvent

Struct PsciMemProtectFtraceEvent 

pub struct PsciMemProtectFtraceEvent {
    pub count: Option<u64>,
    pub was: Option<u64>,
}

Fields

count: Option<u64>was: Option<u64>

Implementations

Source

impl PsciMemProtectFtraceEvent

pub fn count(&self) -> u64

Returns the value of count, or the default value if count is unset.

pub fn was(&self) -> u64

Returns the value of was, or the default value if was is unset.