ReadyThreadEtwEvent

Struct ReadyThreadEtwEvent 

pub struct ReadyThreadEtwEvent {
    pub t_thread_id: Option<u32>,
    pub adjust_increment: Option<i32>,
    pub adjust_reason_enum_or_int: Option<AdjustReasonEnumOrInt>,
    pub flag_enum_or_int: Option<FlagEnumOrInt>,
}
Proto definition based on the Thread_v2 CSwitch class definition See: https://learn.microsoft.com/en-us/windows/win32/etw/readythread

Fields

t_thread_id: Option<u32>

The thread identifier of the thread being readied for execution.

adjust_increment: Option<i32>

The value by which the priority is being adjusted.

adjust_reason_enum_or_int: Option<AdjustReasonEnumOrInt>flag_enum_or_int: Option<FlagEnumOrInt>

Implementations

Source

impl ReadyThreadEtwEvent

pub fn t_thread_id(&self) -> u32

Returns the value of t_thread_id, or the default value if t_thread_id is unset.

pub fn adjust_increment(&self) -> i32

Returns the value of adjust_increment, or the default value if adjust_increment is unset.