pub struct RecoveredTraceInfo {
pub reason: Option<i32>,
pub original_file_size_bytes: Option<u64>,
pub bytes_truncated: Option<u64>,
}Expand description
Injected into TracePacket by perfetto post-reboot recovery to record recovered trace metadata.
Fields
reason: Option<i32>original_file_size_bytes: Option<u64>Raw trace file size (in bytes) on disk prior to post-reboot recovery.
bytes_truncated: Option<u64>Amount of trailing corrupted/incomplete bytes truncated during recovery.
Implementations
Sourceimpl RecoveredTraceInfo
impl RecoveredTraceInfo
Sourcepub fn reason(&self) -> Reason
pub fn reason(&self) -> Reason
Returns the enum value of reason, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: Reason)
pub fn set_reason(&mut self, value: Reason)
Sets reason to the provided enum value.
Sourcepub fn original_file_size_bytes(&self) -> u64
pub fn original_file_size_bytes(&self) -> u64
Returns the value of original_file_size_bytes, or the default value if original_file_size_bytes is unset.
Sourcepub fn bytes_truncated(&self) -> u64
pub fn bytes_truncated(&self) -> u64
Returns the value of bytes_truncated, or the default value if bytes_truncated is unset.