SchedBlockedReasonFtraceEvent

Struct SchedBlockedReasonFtraceEvent 

pub struct SchedBlockedReasonFtraceEvent {
    pub pid: Option<i32>,
    pub caller: Option<u64>,
    pub io_wait: Option<u32>,
}

Fields

pid: Option<i32>caller: Option<u64>io_wait: Option<u32>

Implementations

Source

impl SchedBlockedReasonFtraceEvent

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn caller(&self) -> u64

Returns the value of caller, or the default value if caller is unset.

pub fn io_wait(&self) -> u32

Returns the value of io_wait, or the default value if io_wait is unset.