SchedCpuHotplugFtraceEvent

Struct SchedCpuHotplugFtraceEvent 

pub struct SchedCpuHotplugFtraceEvent {
    pub affected_cpu: Option<i32>,
    pub error: Option<i32>,
    pub status: Option<i32>,
}

Fields

affected_cpu: Option<i32>error: Option<i32>status: Option<i32>

Implementations

Source

impl SchedCpuHotplugFtraceEvent

pub fn affected_cpu(&self) -> i32

Returns the value of affected_cpu, or the default value if affected_cpu is unset.

pub fn error(&self) -> i32

Returns the value of error, or the default value if error is unset.

pub fn status(&self) -> i32

Returns the value of status, or the default value if status is unset.