SchedGroupTrackerFtraceEvent

Struct SchedGroupTrackerFtraceEvent 

pub struct SchedGroupTrackerFtraceEvent {
    pub comm: Option<String>,
    pub pid: Option<i32>,
    pub group: Option<String>,
    pub group_num: Option<i32>,
}

Fields

comm: Option<String>pid: Option<i32>group: Option<String>group_num: Option<i32>

Implementations

Source

impl SchedGroupTrackerFtraceEvent

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn group(&self) -> &str

Returns the value of group, or the default value if group is unset.

pub fn group_num(&self) -> i32

Returns the value of group_num, or the default value if group_num is unset.