SchedSwitchWithCtrsFtraceEvent

Struct SchedSwitchWithCtrsFtraceEvent 

pub struct SchedSwitchWithCtrsFtraceEvent {
Show 23 fields pub old_pid: Option<i32>, pub new_pid: Option<i32>, pub cctr: Option<u64>, pub ctr0: Option<u64>, pub ctr1: Option<u64>, pub ctr2: Option<u64>, pub ctr3: Option<u64>, pub lctr0: Option<u32>, pub lctr1: Option<u32>, pub ctr4: Option<u64>, pub ctr5: Option<u64>, pub prev_comm: Option<String>, pub prev_pid: Option<i32>, pub cyc: Option<u32>, pub inst: Option<u32>, pub stallbm: Option<u32>, pub l3dm: Option<u32>, pub next_pid: Option<i32>, pub next_comm: Option<String>, pub prev_state: Option<i64>, pub amu0: Option<u64>, pub amu1: Option<u64>, pub amu2: Option<u64>,
}

Fields

old_pid: Option<i32>new_pid: Option<i32>cctr: Option<u64>ctr0: Option<u64>ctr1: Option<u64>ctr2: Option<u64>ctr3: Option<u64>lctr0: Option<u32>lctr1: Option<u32>ctr4: Option<u64>ctr5: Option<u64>prev_comm: Option<String>prev_pid: Option<i32>cyc: Option<u32>inst: Option<u32>stallbm: Option<u32>l3dm: Option<u32>next_pid: Option<i32>next_comm: Option<String>prev_state: Option<i64>amu0: Option<u64>amu1: Option<u64>amu2: Option<u64>

Implementations

Source

impl SchedSwitchWithCtrsFtraceEvent

pub fn old_pid(&self) -> i32

Returns the value of old_pid, or the default value if old_pid is unset.

pub fn new_pid(&self) -> i32

Returns the value of new_pid, or the default value if new_pid is unset.

pub fn cctr(&self) -> u64

Returns the value of cctr, or the default value if cctr is unset.

pub fn ctr0(&self) -> u64

Returns the value of ctr0, or the default value if ctr0 is unset.

pub fn ctr1(&self) -> u64

Returns the value of ctr1, or the default value if ctr1 is unset.

pub fn ctr2(&self) -> u64

Returns the value of ctr2, or the default value if ctr2 is unset.

pub fn ctr3(&self) -> u64

Returns the value of ctr3, or the default value if ctr3 is unset.

pub fn lctr0(&self) -> u32

Returns the value of lctr0, or the default value if lctr0 is unset.

pub fn lctr1(&self) -> u32

Returns the value of lctr1, or the default value if lctr1 is unset.

pub fn ctr4(&self) -> u64

Returns the value of ctr4, or the default value if ctr4 is unset.

pub fn ctr5(&self) -> u64

Returns the value of ctr5, or the default value if ctr5 is unset.

pub fn prev_comm(&self) -> &str

Returns the value of prev_comm, or the default value if prev_comm is unset.

pub fn prev_pid(&self) -> i32

Returns the value of prev_pid, or the default value if prev_pid is unset.

pub fn cyc(&self) -> u32

Returns the value of cyc, or the default value if cyc is unset.

pub fn inst(&self) -> u32

Returns the value of inst, or the default value if inst is unset.

pub fn stallbm(&self) -> u32

Returns the value of stallbm, or the default value if stallbm is unset.

pub fn l3dm(&self) -> u32

Returns the value of l3dm, or the default value if l3dm is unset.

pub fn next_pid(&self) -> i32

Returns the value of next_pid, or the default value if next_pid is unset.

pub fn next_comm(&self) -> &str

Returns the value of next_comm, or the default value if next_comm is unset.

pub fn prev_state(&self) -> i64

Returns the value of prev_state, or the default value if prev_state is unset.

pub fn amu0(&self) -> u64

Returns the value of amu0, or the default value if amu0 is unset.

pub fn amu1(&self) -> u64

Returns the value of amu1, or the default value if amu1 is unset.

pub fn amu2(&self) -> u64

Returns the value of amu2, or the default value if amu2 is unset.