SchedWakeupTaskAttrFtraceEvent

Struct SchedWakeupTaskAttrFtraceEvent 

pub struct SchedWakeupTaskAttrFtraceEvent {
    pub pid: Option<i32>,
    pub cpu_affinity: Option<u64>,
    pub task_util: Option<u64>,
    pub uclamp_min: Option<u64>,
    pub vruntime: Option<u64>,
}

Fields

pid: Option<i32>cpu_affinity: Option<u64>task_util: Option<u64>uclamp_min: Option<u64>vruntime: Option<u64>

Implementations

Source

impl SchedWakeupTaskAttrFtraceEvent

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn cpu_affinity(&self) -> u64

Returns the value of cpu_affinity, or the default value if cpu_affinity is unset.

pub fn task_util(&self) -> u64

Returns the value of task_util, or the default value if task_util is unset.

pub fn uclamp_min(&self) -> u64

Returns the value of uclamp_min, or the default value if uclamp_min is unset.

pub fn vruntime(&self) -> u64

Returns the value of vruntime, or the default value if vruntime is unset.