SchedWakingFtraceEvent

Struct SchedWakingFtraceEvent 

pub struct SchedWakingFtraceEvent {
    pub comm: Option<String>,
    pub pid: Option<i32>,
    pub prio: Option<i32>,
    pub success: Option<i32>,
    pub target_cpu: Option<i32>,
}

Fields

comm: Option<String>pid: Option<i32>prio: Option<i32>success: Option<i32>target_cpu: Option<i32>

Implementations

Source

impl SchedWakingFtraceEvent

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn prio(&self) -> i32

Returns the value of prio, or the default value if prio is unset.

pub fn success(&self) -> i32

Returns the value of success, or the default value if success is unset.

pub fn target_cpu(&self) -> i32

Returns the value of target_cpu, or the default value if target_cpu is unset.