ScsiDispatchCmdErrorFtraceEvent

Struct ScsiDispatchCmdErrorFtraceEvent 

pub struct ScsiDispatchCmdErrorFtraceEvent {
Show 13 fields pub host_no: Option<u32>, pub channel: Option<u32>, pub id: Option<u32>, pub lun: Option<u32>, pub rtn: Option<i32>, pub opcode: Option<u32>, pub cmd_len: Option<u32>, pub data_sglen: Option<u32>, pub prot_sglen: Option<u32>, pub prot_op: Option<u32>, pub driver_tag: Option<i32>, pub scheduler_tag: Option<i32>, pub cmnd: Option<Vec<u8>>,
}

Fields

host_no: Option<u32>channel: Option<u32>id: Option<u32>lun: Option<u32>rtn: Option<i32>opcode: Option<u32>cmd_len: Option<u32>data_sglen: Option<u32>prot_sglen: Option<u32>prot_op: Option<u32>driver_tag: Option<i32>scheduler_tag: Option<i32>cmnd: Option<Vec<u8>>

Implementations

Source

impl ScsiDispatchCmdErrorFtraceEvent

pub fn host_no(&self) -> u32

Returns the value of host_no, or the default value if host_no is unset.

pub fn channel(&self) -> u32

Returns the value of channel, or the default value if channel is unset.

pub fn id(&self) -> u32

Returns the value of id, or the default value if id is unset.

pub fn lun(&self) -> u32

Returns the value of lun, or the default value if lun is unset.

pub fn rtn(&self) -> i32

Returns the value of rtn, or the default value if rtn is unset.

pub fn opcode(&self) -> u32

Returns the value of opcode, or the default value if opcode is unset.

pub fn cmd_len(&self) -> u32

Returns the value of cmd_len, or the default value if cmd_len is unset.

pub fn data_sglen(&self) -> u32

Returns the value of data_sglen, or the default value if data_sglen is unset.

pub fn prot_sglen(&self) -> u32

Returns the value of prot_sglen, or the default value if prot_sglen is unset.

pub fn prot_op(&self) -> u32

Returns the value of prot_op, or the default value if prot_op is unset.

pub fn driver_tag(&self) -> i32

Returns the value of driver_tag, or the default value if driver_tag is unset.

pub fn scheduler_tag(&self) -> i32

Returns the value of scheduler_tag, or the default value if scheduler_tag is unset.

pub fn cmnd(&self) -> &[u8]

Returns the value of cmnd, or the default value if cmnd is unset.