SignalGenerateFtraceEvent

Struct SignalGenerateFtraceEvent 

pub struct SignalGenerateFtraceEvent {
    pub code: Option<i32>,
    pub comm: Option<String>,
    pub group: Option<i32>,
    pub pid: Option<i32>,
    pub result: Option<i32>,
    pub sig: Option<i32>,
}

Fields

code: Option<i32>comm: Option<String>group: Option<i32>pid: Option<i32>result: Option<i32>sig: Option<i32>

Implementations

Source

impl SignalGenerateFtraceEvent

pub fn code(&self) -> i32

Returns the value of code, or the default value if code is unset.

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn group(&self) -> i32

Returns the value of group, or the default value if group is unset.

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn result(&self) -> i32

Returns the value of result, or the default value if result is unset.

pub fn sig(&self) -> i32

Returns the value of sig, or the default value if sig is unset.