pub struct SmapsConfig {
pub vma_fields: Vec<i32>,
pub unaggregated: Option<bool>,
pub name_redaction_rules: Vec<RedactionRule>,
}Expand description
Config for collecting /proc/pid/smaps.
Fields
vma_fields: Vec<i32>Set of fields to collect. If unset, defaults to: size, rss, anonymous, swap.
unaggregated: Option<bool>If false, mappings are aggregated by their path name. If true, each mapping is serialised separately.
name_redaction_rules: Vec<RedactionRule>Optional ordered list of redaction rules for the name of the mapping. Note that all mappings will still be emitted, these rules only affect the emitted name. If unset, all names are written as is. If set, the first matching rule decides on the action. If no rules match, the name is written as is.
Implementations
Sourceimpl SmapsConfig
impl SmapsConfig
Sourcepub fn vma_fields(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<VmaField>>
pub fn vma_fields( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<VmaField>>
Returns an iterator which yields the valid enum values contained in vma_fields.
Sourcepub fn push_vma_fields(&mut self, value: VmaField)
pub fn push_vma_fields(&mut self, value: VmaField)
Appends the provided enum value to vma_fields.
Sourcepub fn unaggregated(&self) -> bool
pub fn unaggregated(&self) -> bool
Returns the value of unaggregated, or the default value if unaggregated is unset.