SmapsEntry

Struct SmapsEntry 

pub struct SmapsEntry {
Show 15 fields pub path: Option<String>, pub size_kb: Option<u64>, pub private_dirty_kb: Option<u64>, pub swap_kb: Option<u64>, pub file_name: Option<String>, pub start_address: Option<u64>, pub module_timestamp: Option<u64>, pub module_debugid: Option<String>, pub module_debug_path: Option<String>, pub protection_flags: Option<u32>, pub private_clean_resident_kb: Option<u64>, pub shared_dirty_resident_kb: Option<u64>, pub shared_clean_resident_kb: Option<u64>, pub locked_kb: Option<u64>, pub proportional_resident_kb: Option<u64>,
}

Fields

path: Option<String>size_kb: Option<u64>private_dirty_kb: Option<u64>swap_kb: Option<u64>file_name: Option<String>

for field upload (instead of path).

start_address: Option<u64>

Fields below added and used only for Chromium memory infra, see crbug.com/1098746.

module_timestamp: Option<u64>module_debugid: Option<String>module_debug_path: Option<String>protection_flags: Option<u32>private_clean_resident_kb: Option<u64>shared_dirty_resident_kb: Option<u64>shared_clean_resident_kb: Option<u64>locked_kb: Option<u64>proportional_resident_kb: Option<u64>

Implementations

Source

impl SmapsEntry

pub fn path(&self) -> &str

Returns the value of path, or the default value if path is unset.

pub fn size_kb(&self) -> u64

Returns the value of size_kb, or the default value if size_kb is unset.

pub fn private_dirty_kb(&self) -> u64

Returns the value of private_dirty_kb, or the default value if private_dirty_kb is unset.

pub fn swap_kb(&self) -> u64

Returns the value of swap_kb, or the default value if swap_kb is unset.

pub fn file_name(&self) -> &str

Returns the value of file_name, or the default value if file_name is unset.

pub fn start_address(&self) -> u64

Returns the value of start_address, or the default value if start_address is unset.

pub fn module_timestamp(&self) -> u64

Returns the value of module_timestamp, or the default value if module_timestamp is unset.

pub fn module_debugid(&self) -> &str

Returns the value of module_debugid, or the default value if module_debugid is unset.

pub fn module_debug_path(&self) -> &str

Returns the value of module_debug_path, or the default value if module_debug_path is unset.

pub fn protection_flags(&self) -> u32

Returns the value of protection_flags, or the default value if protection_flags is unset.

pub fn private_clean_resident_kb(&self) -> u64

Returns the value of private_clean_resident_kb, or the default value if private_clean_resident_kb is unset.

pub fn shared_dirty_resident_kb(&self) -> u64

Returns the value of shared_dirty_resident_kb, or the default value if shared_dirty_resident_kb is unset.

pub fn shared_clean_resident_kb(&self) -> u64

Returns the value of shared_clean_resident_kb, or the default value if shared_clean_resident_kb is unset.

pub fn locked_kb(&self) -> u64

Returns the value of locked_kb, or the default value if locked_kb is unset.

pub fn proportional_resident_kb(&self) -> u64

Returns the value of proportional_resident_kb, or the default value if proportional_resident_kb is unset.