pub struct StreamingFree {
pub address: Vec<u64>,
pub heap_id: Vec<u32>,
pub sequence_number: Vec<u64>,
}Expand description
Packet emitted by heapprofd when stream_allocations = true. Only for local testing. Doesn’t report the callsite.
Fields
address: Vec<u64>TODO(fmayer): Add callstack.
heap_id: Vec<u32>sequence_number: Vec<u64>Trait Implementations
Sourceimpl Clone for StreamingFree
impl Clone for StreamingFree
Sourcefn clone(&self) -> StreamingFree
fn clone(&self) -> StreamingFree
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamingFree
impl Debug for StreamingFree
Sourceimpl Default for StreamingFree
impl Default for StreamingFree
Sourceimpl Hash for StreamingFree
impl Hash for StreamingFree
Sourceimpl Message for StreamingFree
impl Message for StreamingFree
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StreamingFree
impl PartialEq for StreamingFree
Sourcefn eq(&self, other: &StreamingFree) -> bool
fn eq(&self, other: &StreamingFree) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for StreamingFree
impl StructuralPartialEq for StreamingFree