SystemdJournaldEvent

Struct SystemdJournaldEvent 

pub struct SystemdJournaldEvent {
Show 14 fields pub pid: Option<u32>, pub tid: Option<u32>, pub uid: Option<u32>, pub gid: Option<u32>, pub prio: Option<u32>, pub tag: Option<String>, pub message: Option<String>, pub comm: Option<String>, pub exe: Option<String>, pub systemd_unit: Option<String>, pub hostname: Option<String>, pub transport: Option<String>, pub num_total: Option<u64>, pub num_failed: Option<u64>,
}
A journald log event packet, collected from the Linux systemd journal. Emitted by the “linux.systemd_journald” data source in traced_probes. Next field id: 13, statistics starting at 20

Fields

pid: Option<u32>

_PID: PID of the process that wrote the log entry (trusted).

tid: Option<u32>

_TID: thread ID of the logging thread (trusted, set by journald for native journal protocol entries). Absent for syslog, stdout-piped, and kernel entries.

uid: Option<u32>

_UID: user ID of the process (trusted).

gid: Option<u32>

_GID: group ID of the process (trusted).

prio: Option<u32>

PRIORITY: syslog priority level 0 (EMERG) .. 7 (DEBUG).

tag: Option<String>

SYSLOG_IDENTIFIER: program name / tag, set by the logging application.

message: Option<String>

MESSAGE: the human-readable log message text.

comm: Option<String>

_COMM: short process name as known to the kernel (trusted).

exe: Option<String>

_EXE: full executable path (trusted).

systemd_unit: Option<String>

_SYSTEMD_UNIT: the systemd unit that owns this process (trusted).

hostname: Option<String>

_HOSTNAME: hostname of the machine (trusted).

transport: Option<String>

_TRANSPORT: how the entry was received by journald (trusted). Values: “audit”, “driver”, “syslog”, “journal”, “stdout”, “kernel”.

num_total: Option<u64>

These statistics emitted once on Flush()

num_failed: Option<u64>

Implementations

Source

impl SystemdJournaldEvent

pub fn pid(&self) -> u32

Returns the value of pid, or the default value if pid is unset.

pub fn tid(&self) -> u32

Returns the value of tid, or the default value if tid is unset.

pub fn uid(&self) -> u32

Returns the value of uid, or the default value if uid is unset.

pub fn gid(&self) -> u32

Returns the value of gid, or the default value if gid is unset.

pub fn prio(&self) -> u32

Returns the value of prio, or the default value if prio is unset.

pub fn tag(&self) -> &str

Returns the value of tag, or the default value if tag is unset.

pub fn message(&self) -> &str

Returns the value of message, or the default value if message is unset.

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn exe(&self) -> &str

Returns the value of exe, or the default value if exe is unset.

pub fn systemd_unit(&self) -> &str

Returns the value of systemd_unit, or the default value if systemd_unit is unset.

pub fn hostname(&self) -> &str

Returns the value of hostname, or the default value if hostname is unset.

pub fn transport(&self) -> &str

Returns the value of transport, or the default value if transport is unset.

pub fn num_total(&self) -> u64

Returns the value of num_total, or the default value if num_total is unset.

pub fn num_failed(&self) -> u64

Returns the value of num_failed, or the default value if num_failed is unset.