TaskNewtaskFtraceEvent

Struct TaskNewtaskFtraceEvent 

pub struct TaskNewtaskFtraceEvent {
    pub pid: Option<i32>,
    pub comm: Option<String>,
    pub clone_flags: Option<u64>,
    pub oom_score_adj: Option<i32>,
}

Fields

pid: Option<i32>comm: Option<String>clone_flags: Option<u64>oom_score_adj: Option<i32>

Implementations

Source

impl TaskNewtaskFtraceEvent

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn comm(&self) -> &str

Returns the value of comm, or the default value if comm is unset.

pub fn clone_flags(&self) -> u64

Returns the value of clone_flags, or the default value if clone_flags is unset.

pub fn oom_score_adj(&self) -> i32

Returns the value of oom_score_adj, or the default value if oom_score_adj is unset.