TaskRenameFtraceEvent

Struct TaskRenameFtraceEvent 

pub struct TaskRenameFtraceEvent {
    pub pid: Option<i32>,
    pub oldcomm: Option<String>,
    pub newcomm: Option<String>,
    pub oom_score_adj: Option<i32>,
}

Fields

pid: Option<i32>oldcomm: Option<String>newcomm: Option<String>oom_score_adj: Option<i32>

Implementations

Source

impl TaskRenameFtraceEvent

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn oldcomm(&self) -> &str

Returns the value of oldcomm, or the default value if oldcomm is unset.

pub fn newcomm(&self) -> &str

Returns the value of newcomm, or the default value if newcomm is unset.

pub fn oom_score_adj(&self) -> i32

Returns the value of oom_score_adj, or the default value if oom_score_adj is unset.