TcpRetransmitSkbFtraceEvent

Struct TcpRetransmitSkbFtraceEvent 

pub struct TcpRetransmitSkbFtraceEvent {
    pub daddr: Option<u32>,
    pub dport: Option<u32>,
    pub saddr: Option<u32>,
    pub skaddr: Option<u64>,
    pub skbaddr: Option<u64>,
    pub sport: Option<u32>,
    pub state: Option<i32>,
}

Fields

daddr: Option<u32>dport: Option<u32>saddr: Option<u32>skaddr: Option<u64>skbaddr: Option<u64>sport: Option<u32>state: Option<i32>

Implementations

Source

impl TcpRetransmitSkbFtraceEvent

pub fn daddr(&self) -> u32

Returns the value of daddr, or the default value if daddr is unset.

pub fn dport(&self) -> u32

Returns the value of dport, or the default value if dport is unset.

pub fn saddr(&self) -> u32

Returns the value of saddr, or the default value if saddr is unset.

pub fn skaddr(&self) -> u64

Returns the value of skaddr, or the default value if skaddr is unset.

pub fn skbaddr(&self) -> u64

Returns the value of skbaddr, or the default value if skbaddr is unset.

pub fn sport(&self) -> u32

Returns the value of sport, or the default value if sport is unset.

pub fn state(&self) -> i32

Returns the value of state, or the default value if state is unset.