ThreadDescriptor

Struct ThreadDescriptor 

pub struct ThreadDescriptor {
    pub pid: Option<i32>,
    pub tid: Option<i64>,
    pub thread_name: Option<String>,
    pub chrome_thread_type: Option<i32>,
    pub reference_timestamp_us: Option<i64>,
    pub reference_thread_time_us: Option<i64>,
    pub reference_thread_instruction_count: Option<i64>,
    pub legacy_sort_index: Option<i32>,
}
Describes a thread’s attributes. Emitted as part of a TrackDescriptor, usually by the thread’s trace writer.

Next id: 9.

Fields

pid: Option<i32>tid: Option<i64>thread_name: Option<String>chrome_thread_type: Option<i32>reference_timestamp_us: Option<i64>

Deprecated. Use ClockSnapshot in combination with TracePacket’s timestamp and timestamp_clock_id fields instead.

reference_thread_time_us: Option<i64>

Absolute reference values. Clock values in subsequent TrackEvents can be encoded accumulatively and relative to these. This reduces their var-int encoding size. TODO(eseckler): Deprecated. Replace these with ClockSnapshot encoding.

reference_thread_instruction_count: Option<i64>legacy_sort_index: Option<i32>

To support old UI. New UI should determine default sorting by thread_type.

Implementations

Source

impl ThreadDescriptor

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn tid(&self) -> i64

Returns the value of tid, or the default value if tid is unset.

pub fn legacy_sort_index(&self) -> i32

Returns the value of legacy_sort_index, or the default value if legacy_sort_index is unset.

pub fn chrome_thread_type(&self) -> ChromeThreadType

Returns the enum value of chrome_thread_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_chrome_thread_type(&mut self, value: ChromeThreadType)

Sets chrome_thread_type to the provided enum value.

pub fn thread_name(&self) -> &str

Returns the value of thread_name, or the default value if thread_name is unset.

pub fn reference_timestamp_us(&self) -> i64

Returns the value of reference_timestamp_us, or the default value if reference_timestamp_us is unset.

pub fn reference_thread_time_us(&self) -> i64

Returns the value of reference_thread_time_us, or the default value if reference_thread_time_us is unset.

pub fn reference_thread_instruction_count(&self) -> i64

Returns the value of reference_thread_instruction_count, or the default value if reference_thread_instruction_count is unset.