pub struct TimerStartFtraceEvent {
pub timer: Option<u64>,
pub function: Option<u64>,
pub expires: Option<u64>,
pub now: Option<u64>,
pub deferrable: Option<u32>,
pub flags: Option<u32>,
pub bucket_expiry: Option<u64>,
}Fields
timer: Option<u64>function: Option<u64>expires: Option<u64>now: Option<u64>deferrable: Option<u32>flags: Option<u32>bucket_expiry: Option<u64>Implementations
Sourceimpl TimerStartFtraceEvent
impl TimerStartFtraceEvent
Sourcepub fn function(&self) -> u64
pub fn function(&self) -> u64
Returns the value of function, or the default value if function is unset.
Sourcepub fn expires(&self) -> u64
pub fn expires(&self) -> u64
Returns the value of expires, or the default value if expires is unset.
Sourcepub fn deferrable(&self) -> u32
pub fn deferrable(&self) -> u32
Returns the value of deferrable, or the default value if deferrable is unset.
Sourcepub fn bucket_expiry(&self) -> u64
pub fn bucket_expiry(&self) -> u64
Returns the value of bucket_expiry, or the default value if bucket_expiry is unset.