TrustyIpcConnectFtraceEvent

Struct TrustyIpcConnectFtraceEvent 

pub struct TrustyIpcConnectFtraceEvent {
    pub chan: Option<u32>,
    pub port: Option<String>,
    pub state: Option<i32>,
}

Fields

chan: Option<u32>port: Option<String>state: Option<i32>

Implementations

Source

impl TrustyIpcConnectFtraceEvent

pub fn chan(&self) -> u32

Returns the value of chan, or the default value if chan is unset.

pub fn port(&self) -> &str

Returns the value of port, or the default value if port is unset.

pub fn state(&self) -> i32

Returns the value of state, or the default value if state is unset.