TrustyShareMemoryDoneFtraceEvent

Struct TrustyShareMemoryDoneFtraceEvent 

pub struct TrustyShareMemoryDoneFtraceEvent {
    pub handle: Option<u64>,
    pub len: Option<u64>,
    pub lend: Option<u32>,
    pub nents: Option<u32>,
    pub ret: Option<i32>,
}

Fields

handle: Option<u64>len: Option<u64>lend: Option<u32>nents: Option<u32>ret: Option<i32>

Implementations

Source

impl TrustyShareMemoryDoneFtraceEvent

pub fn handle(&self) -> u64

Returns the value of handle, or the default value if handle is unset.

pub fn len(&self) -> u64

Returns the value of len, or the default value if len is unset.

pub fn lend(&self) -> u32

Returns the value of lend, or the default value if lend is unset.

pub fn nents(&self) -> u32

Returns the value of nents, or the default value if nents is unset.

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.