TrustyShareMemoryFtraceEvent

Struct TrustyShareMemoryFtraceEvent 

pub struct TrustyShareMemoryFtraceEvent {
    pub len: Option<u64>,
    pub lend: Option<u32>,
    pub nents: Option<u32>,
}

Fields

len: Option<u64>lend: Option<u32>nents: Option<u32>

Implementations

Source

impl TrustyShareMemoryFtraceEvent

pub fn len(&self) -> u64

Returns the value of len, or the default value if len is unset.

pub fn lend(&self) -> u32

Returns the value of lend, or the default value if lend is unset.

pub fn nents(&self) -> u32

Returns the value of nents, or the default value if nents is unset.