UfshcdCommandFtraceEvent

Struct UfshcdCommandFtraceEvent 

pub struct UfshcdCommandFtraceEvent {
    pub dev_name: Option<String>,
    pub doorbell: Option<u32>,
    pub intr: Option<u32>,
    pub lba: Option<u64>,
    pub opcode: Option<u32>,
    pub str: Option<String>,
    pub tag: Option<u32>,
    pub transfer_len: Option<i32>,
    pub group_id: Option<u32>,
    pub str_t: Option<u32>,
}

Fields

dev_name: Option<String>doorbell: Option<u32>intr: Option<u32>lba: Option<u64>opcode: Option<u32>str: Option<String>tag: Option<u32>transfer_len: Option<i32>group_id: Option<u32>str_t: Option<u32>

Implementations

Source

impl UfshcdCommandFtraceEvent

pub fn dev_name(&self) -> &str

Returns the value of dev_name, or the default value if dev_name is unset.

pub fn doorbell(&self) -> u32

Returns the value of doorbell, or the default value if doorbell is unset.

pub fn intr(&self) -> u32

Returns the value of intr, or the default value if intr is unset.

pub fn lba(&self) -> u64

Returns the value of lba, or the default value if lba is unset.

pub fn opcode(&self) -> u32

Returns the value of opcode, or the default value if opcode is unset.

pub fn str(&self) -> &str

Returns the value of str, or the default value if str is unset.

pub fn tag(&self) -> u32

Returns the value of tag, or the default value if tag is unset.

pub fn transfer_len(&self) -> i32

Returns the value of transfer_len, or the default value if transfer_len is unset.

pub fn group_id(&self) -> u32

Returns the value of group_id, or the default value if group_id is unset.

pub fn str_t(&self) -> u32

Returns the value of str_t, or the default value if str_t is unset.