V8InternalCode

Struct V8InternalCode 

pub struct V8InternalCode {
    pub v8_isolate_iid: Option<u64>,
    pub tid: Option<u32>,
    pub name: Option<String>,
    pub type: Option<i32>,
    pub builtin_id: Option<i32>,
    pub instruction_start: Option<u64>,
    pub instruction_size_bytes: Option<u64>,
    pub machine_code: Option<Vec<u8>>,
}

Fields

v8_isolate_iid: Option<u64>tid: Option<u32>name: Option<String>type: Option<i32>builtin_id: Option<i32>instruction_start: Option<u64>instruction_size_bytes: Option<u64>machine_code: Option<Vec<u8>>

Implementations

Source

impl V8InternalCode

pub fn v8_isolate_iid(&self) -> u64

Returns the value of v8_isolate_iid, or the default value if v8_isolate_iid is unset.

pub fn tid(&self) -> u32

Returns the value of tid, or the default value if tid is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn type(&self) -> Type

Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.

pub fn set_type(&mut self, value: Type)

Sets type to the provided enum value.

pub fn builtin_id(&self) -> i32

Returns the value of builtin_id, or the default value if builtin_id is unset.

pub fn instruction_start(&self) -> u64

Returns the value of instruction_start, or the default value if instruction_start is unset.

pub fn instruction_size_bytes(&self) -> u64

Returns the value of instruction_size_bytes, or the default value if instruction_size_bytes is unset.

pub fn machine_code(&self) -> &[u8]

Returns the value of machine_code, or the default value if machine_code is unset.