V8WasmCode

Struct V8WasmCode 

pub struct V8WasmCode {
    pub v8_isolate_iid: Option<u64>,
    pub tid: Option<u32>,
    pub v8_wasm_script_iid: Option<u64>,
    pub function_name: Option<String>,
    pub tier: Option<i32>,
    pub code_offset_in_module: Option<i32>,
    pub instruction_start: Option<u64>,
    pub instruction_size_bytes: Option<u64>,
    pub machine_code: Option<Vec<u8>>,
}

Fields

v8_isolate_iid: Option<u64>tid: Option<u32>v8_wasm_script_iid: Option<u64>function_name: Option<String>tier: Option<i32>code_offset_in_module: Option<i32>instruction_start: Option<u64>instruction_size_bytes: Option<u64>machine_code: Option<Vec<u8>>

Implementations

Source

impl V8WasmCode

pub fn v8_isolate_iid(&self) -> u64

Returns the value of v8_isolate_iid, or the default value if v8_isolate_iid is unset.

pub fn tid(&self) -> u32

Returns the value of tid, or the default value if tid is unset.

pub fn v8_wasm_script_iid(&self) -> u64

Returns the value of v8_wasm_script_iid, or the default value if v8_wasm_script_iid is unset.

pub fn function_name(&self) -> &str

Returns the value of function_name, or the default value if function_name is unset.

pub fn tier(&self) -> Tier

Returns the enum value of tier, or the default if the field is unset or set to an invalid enum value.

pub fn set_tier(&mut self, value: Tier)

Sets tier to the provided enum value.

pub fn code_offset_in_module(&self) -> i32

Returns the value of code_offset_in_module, or the default value if code_offset_in_module is unset.

pub fn instruction_start(&self) -> u64

Returns the value of instruction_start, or the default value if instruction_start is unset.

pub fn instruction_size_bytes(&self) -> u64

Returns the value of instruction_size_bytes, or the default value if instruction_size_bytes is unset.

pub fn machine_code(&self) -> &[u8]

Returns the value of machine_code, or the default value if machine_code is unset.