ThermalZone

Struct ThermalZone 

pub struct ThermalZone {
    pub name: Option<String>,
    pub temp: Option<u64>,
    pub type: Option<String>,
}
Reading from /sys/class/thermal/*.

Fields

name: Option<String>temp: Option<u64>type: Option<String>

Implementations

Source

impl ThermalZone

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn temp(&self) -> u64

Returns the value of temp, or the default value if temp is unset.

pub fn type(&self) -> &str

Returns the value of type, or the default value if type is unset.