OptionalTrustedUid

Enum OptionalTrustedUid 

pub enum OptionalTrustedUid {
    TrustedUid(i32),
}
Trusted user id of the producer which generated this packet. Keep in sync with TrustedPacket.trusted_uid.

TODO(eseckler): Emit this field in a PacketSequenceDescriptor message instead.

Variants



TrustedUid(i32)

Implementations

Source

impl OptionalTrustedUid

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<OptionalTrustedUid>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.