#[repr(i32)]pub enum SequenceFlags {
SeqUnspecified = 0,
SeqIncrementalStateCleared = 1,
SeqNeedsIncrementalState = 2,
}Variants
SeqUnspecified = 0
SeqIncrementalStateCleared = 1
Set by the writer to indicate that it will re-emit any incremental data for the packet’s sequence before referring to it again. This includes interned data as well as periodically emitted data like Process/ThreadDescriptors. This flag only affects the current packet sequence (see |trusted_packet_sequence_id|).
When set, this TracePacket and subsequent TracePackets on the same sequence will not refer to any incremental data emitted before this TracePacket. For example, previously emitted interned data will be re-emitted if it is referred to again.
When the reader detects packet loss (|previous_packet_dropped|), it needs to skip packets in the sequence until the next one with this flag set, to ensure intact incremental data.
SeqNeedsIncrementalState = 2
This packet requires incremental state, such as TracePacketDefaults or InternedData, to be parsed correctly. The trace reader should skip this packet if incremental state is not valid on this sequence, i.e. if no packet with the SEQ_INCREMENTAL_STATE_CLEARED flag has been seen on the current |trusted_packet_sequence_id|.
Implementations
Sourceimpl SequenceFlags
impl SequenceFlags
Sourceimpl SequenceFlags
impl SequenceFlags
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.