pub struct Callstack {
pub frames: Vec<Frame>,
}Expand description
Inline callstack for TrackEvents when interning is not needed. This is a simplified version of the profiling Callstack/Frame messages, designed for cases where trace size is not critical or callstacks are unique.
Use this for simple callstacks with function names and source locations. For binary/library information (mappings, build IDs, relative PCs), use interned callstacks via callstack_iid instead.
Fields
frames: Vec<Frame>Frames of this callstack, ordered from bottom (outermost) to top (innermost). For example, if main() calls foo() which calls bar(), the frames would be: [main, foo, bar]