LegacyEvent

Struct LegacyEvent 

pub struct LegacyEvent {
Show 14 fields pub name_iid: Option<u64>, pub phase: Option<i32>, pub duration_us: Option<i64>, pub thread_duration_us: Option<i64>, pub thread_instruction_delta: Option<i64>, pub id_scope: Option<String>, pub use_async_tts: Option<bool>, pub bind_id: Option<u64>, pub bind_to_enclosing: Option<bool>, pub flow_direction: Option<i32>, pub instant_event_scope: Option<i32>, pub pid_override: Option<i32>, pub tid_override: Option<i32>, pub id: Option<Id>,
}
Apart from {category, time, thread time, tid, pid}, other legacy trace event attributes are initially simply proxied for conversion to a JSON trace. We intend to gradually transition these attributes to similar native features in TrackEvent (e.g. async + flow events), or deprecate them without replacement where transition is unsuitable.

Next reserved id: 16 (up to 16). Next id: 20.

Fields

name_iid: Option<u64>

Deprecated, use TrackEvent::name(_iid) instead. interned EventName.

phase: Option<i32>duration_us: Option<i64>thread_duration_us: Option<i64>thread_instruction_delta: Option<i64>

Elapsed retired instruction count during the event.

id_scope: Option<String>

Additional optional scope for |id|.

use_async_tts: Option<bool>

Consider the thread timestamps for async BEGIN/END event pairs as valid.

bind_id: Option<u64>

Idenfifies a flow. Flow events with the same bind_id are connected.

bind_to_enclosing: Option<bool>

Use the enclosing slice as binding point for a flow end event instead of the next slice. Flow start/step events always bind to the enclosing slice.

flow_direction: Option<i32>instant_event_scope: Option<i32>pid_override: Option<i32>

Override the pid/tid if the writer needs to emit events on behalf of another process/thread. This should be the exception. Normally, the pid+tid from ThreadDescriptor is used.

tid_override: Option<i32>id: Option<Id>

Implementations

Source

impl LegacyEvent

pub fn name_iid(&self) -> u64

Returns the value of name_iid, or the default value if name_iid is unset.

pub fn phase(&self) -> i32

Returns the value of phase, or the default value if phase is unset.

pub fn duration_us(&self) -> i64

Returns the value of duration_us, or the default value if duration_us is unset.

pub fn thread_duration_us(&self) -> i64

Returns the value of thread_duration_us, or the default value if thread_duration_us is unset.

pub fn id_scope(&self) -> &str

Returns the value of id_scope, or the default value if id_scope is unset.

pub fn bind_id(&self) -> u64

Returns the value of bind_id, or the default value if bind_id is unset.

pub fn use_async_tts(&self) -> bool

Returns the value of use_async_tts, or the default value if use_async_tts is unset.

pub fn bind_to_enclosing(&self) -> bool

Returns the value of bind_to_enclosing, or the default value if bind_to_enclosing is unset.

pub fn flow_direction(&self) -> FlowDirection

Returns the enum value of flow_direction, or the default if the field is unset or set to an invalid enum value.

pub fn set_flow_direction(&mut self, value: FlowDirection)

Sets flow_direction to the provided enum value.

pub fn instant_event_scope(&self) -> InstantEventScope

Returns the enum value of instant_event_scope, or the default if the field is unset or set to an invalid enum value.

pub fn set_instant_event_scope(&mut self, value: InstantEventScope)

Sets instant_event_scope to the provided enum value.

pub fn thread_instruction_delta(&self) -> i64

Returns the value of thread_instruction_delta, or the default value if thread_instruction_delta is unset.

pub fn pid_override(&self) -> i32

Returns the value of pid_override, or the default value if pid_override is unset.

pub fn tid_override(&self) -> i32

Returns the value of tid_override, or the default value if tid_override is unset.