SourceMap

Enum SourceMap 

pub enum SourceMap {
    SourcePositions(Vec<u8>),
    BytecodePositions(Vec<u8>),
    InlinedBytecodePositions(Vec<u8>),
}

Variants



SourcePositions(Vec<u8>)

For Ignition / bytecode:

  • Maps bytecode-ranges to byte offsets (for the same script as the related js function)


BytecodePositions(Vec<u8>)

For Sparkplug code:

  • Maps machine-code ranges to bytecode ranges in the corresponding ignition code object for the same js-function.


InlinedBytecodePositions(Vec<u8>)

For optimized code:

  • Maps machine-code-ranges to bytecode ranges in various ignition code objects (inlining might happen from multiple functions)

Implementations

Source

impl SourceMap

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<SourceMap>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.