VkDebugUtilsObjectName

Struct VkDebugUtilsObjectName 

pub struct VkDebugUtilsObjectName {
    pub pid: Option<u32>,
    pub vk_device: Option<u64>,
    pub object_type: Option<i32>,
    pub object: Option<u64>,
    pub object_name: Option<String>,
}
For recording vkSetDebugUtilsObjectNameEXT and vkDebugMarkerSetObjectNameEXT

Fields

pid: Option<u32>vk_device: Option<u64>object_type: Option<i32>object: Option<u64>object_name: Option<String>

Implementations

Source

impl VkDebugUtilsObjectName

pub fn pid(&self) -> u32

Returns the value of pid, or the default value if pid is unset.

pub fn vk_device(&self) -> u64

Returns the value of vk_device, or the default value if vk_device is unset.

pub fn object_type(&self) -> i32

Returns the value of object_type, or the default value if object_type is unset.

pub fn object(&self) -> u64

Returns the value of object, or the default value if object is unset.

pub fn object_name(&self) -> &str

Returns the value of object_name, or the default value if object_name is unset.