VkQueueSubmit

Struct VkQueueSubmit 

pub struct VkQueueSubmit {
    pub duration_ns: Option<u64>,
    pub pid: Option<u32>,
    pub tid: Option<u32>,
    pub vk_queue: Option<u64>,
    pub vk_command_buffers: Vec<u64>,
    pub submission_id: Option<u32>,
}
For recording vkQueueSubmit call.

Fields

duration_ns: Option<u64>pid: Option<u32>tid: Option<u32>vk_queue: Option<u64>vk_command_buffers: Vec<u64>submission_id: Option<u32>

Submission ID. An identifier unique to each vkQueueSubmit call. This submission_id must match GpuRenderStageEvent.submission_id if the GpuRenderStageEvent is created due to this vkQueueSubmit.

Implementations

Source

impl VkQueueSubmit

pub fn duration_ns(&self) -> u64

Returns the value of duration_ns, or the default value if duration_ns is unset.

pub fn pid(&self) -> u32

Returns the value of pid, or the default value if pid is unset.

pub fn tid(&self) -> u32

Returns the value of tid, or the default value if tid is unset.

pub fn vk_queue(&self) -> u64

Returns the value of vk_queue, or the default value if vk_queue is unset.

pub fn submission_id(&self) -> u32

Returns the value of submission_id, or the default value if submission_id is unset.