pub struct BeginFrameArgs {
pub type: Option<i32>,
pub source_id: Option<u64>,
pub sequence_number: Option<u64>,
pub frame_time_us: Option<i64>,
pub deadline_us: Option<i64>,
pub interval_delta_us: Option<i64>,
pub on_critical_path: Option<bool>,
pub animate_only: Option<bool>,
pub frames_throttled_since_last: Option<i64>,
pub created_from: Option<CreatedFrom>,
}Expand description
Next id: 13
Fields
type: Option<i32>source_id: Option<u64>sequence_number: Option<u64>frame_time_us: Option<i64>deadline_us: Option<i64>interval_delta_us: Option<i64>on_critical_path: Option<bool>animate_only: Option<bool>frames_throttled_since_last: Option<i64>created_from: Option<CreatedFrom>Implementations
Sourceimpl BeginFrameArgs
impl BeginFrameArgs
Sourcepub fn type(&self) -> BeginFrameArgsType
pub fn type(&self) -> BeginFrameArgsType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: BeginFrameArgsType)
pub fn set_type(&mut self, value: BeginFrameArgsType)
Sets type to the provided enum value.
Sourcepub fn source_id(&self) -> u64
pub fn source_id(&self) -> u64
Returns the value of source_id, or the default value if source_id is unset.
Sourcepub fn sequence_number(&self) -> u64
pub fn sequence_number(&self) -> u64
Returns the value of sequence_number, or the default value if sequence_number is unset.
Sourcepub fn frame_time_us(&self) -> i64
pub fn frame_time_us(&self) -> i64
Returns the value of frame_time_us, or the default value if frame_time_us is unset.
Sourcepub fn deadline_us(&self) -> i64
pub fn deadline_us(&self) -> i64
Returns the value of deadline_us, or the default value if deadline_us is unset.
Sourcepub fn interval_delta_us(&self) -> i64
pub fn interval_delta_us(&self) -> i64
Returns the value of interval_delta_us, or the default value if interval_delta_us is unset.
Sourcepub fn on_critical_path(&self) -> bool
pub fn on_critical_path(&self) -> bool
Returns the value of on_critical_path, or the default value if on_critical_path is unset.
Sourcepub fn animate_only(&self) -> bool
pub fn animate_only(&self) -> bool
Returns the value of animate_only, or the default value if animate_only is unset.
Sourcepub fn frames_throttled_since_last(&self) -> i64
pub fn frames_throttled_since_last(&self) -> i64
Returns the value of frames_throttled_since_last, or the default value if frames_throttled_since_last is unset.