pub struct FtraceKprobeStats {
pub hits: Option<i64>,
pub misses: Option<i64>,
}Expand description
Kprobe statistical data, gathered from /sys/kernel/tracing/kprobe_profile.
Fields
hits: Option<i64>Cumulative number of kprobe events generated for this function
misses: Option<i64>Cumulative number of kprobe events that could not be generated for this function and were missed. This happens when too much nesting happens between a kprobe and its kretprobe, overflowing the maxactives buffer.
Implementations