pub struct PackedSmaps {Show 15 fields
pub string_table: Vec<String>,
pub name_id: Vec<u32>,
pub aggregate_count: Vec<u32>,
pub size_kb: Vec<u64>,
pub rss_kb: Vec<u64>,
pub anonymous_kb: Vec<u64>,
pub swap_kb: Vec<u64>,
pub shared_clean_kb: Vec<u64>,
pub shared_dirty_kb: Vec<u64>,
pub private_clean_kb: Vec<u64>,
pub private_dirty_kb: Vec<u64>,
pub locked_kb: Vec<u64>,
pub pss_kb: Vec<u64>,
pub pss_dirty_kb: Vec<u64>,
pub swap_pss_kb: Vec<u64>,
}Expand description
Structure-of-arrays style smaps packet of a single process. All packed repeated fields, if set, must have the same length.
Fields
string_table: Vec<String>Table of path names. Notes:
- first element is the empty string, serialised explicitly.
- the table might contain duplicates.
name_id: Vec<u32>Interned file paths as an index into |string_table|. Note: the “(deleted)” suffix is kept as part of the string_table entry, and is to be handled during trace import stage. Written only if config.unaggregated == true. Otherwise the string_table is exactly the ordered names of the aggregated mappings.
aggregate_count: Vec<u32>How many mappings were merged by name, summing the values below. Written only if config.unaggregated == false.
size_kb: Vec<u64>rss_kb: Vec<u64>anonymous_kb: Vec<u64>swap_kb: Vec<u64>private_clean_kb: Vec<u64>private_dirty_kb: Vec<u64>locked_kb: Vec<u64>pss_kb: Vec<u64>pss_dirty_kb: Vec<u64>swap_pss_kb: Vec<u64>Trait Implementations
Sourceimpl Clone for PackedSmaps
impl Clone for PackedSmaps
Sourcefn clone(&self) -> PackedSmaps
fn clone(&self) -> PackedSmaps
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackedSmaps
impl Debug for PackedSmaps
Sourceimpl Default for PackedSmaps
impl Default for PackedSmaps
Sourceimpl Message for PackedSmaps
impl Message for PackedSmaps
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PackedSmaps
impl PartialEq for PackedSmaps
Sourcefn eq(&self, other: &PackedSmaps) -> bool
fn eq(&self, other: &PackedSmaps) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PackedSmaps