pub struct SystemInfo {Show 17 fields
pub utsname: Option<Utsname>,
pub android_build_fingerprint: Option<String>,
pub android_device_manufacturer: Option<String>,
pub android_soc_model: Option<String>,
pub android_guest_soc_model: Option<String>,
pub android_hardware_revision: Option<String>,
pub android_storage_model: Option<String>,
pub android_ram_model: Option<String>,
pub android_serial_console: Option<String>,
pub tracing_service_version: Option<String>,
pub android_sdk_version: Option<u64>,
pub page_size: Option<u32>,
pub num_cpus: Option<u32>,
pub timezone_off_mins: Option<i32>,
pub hz: Option<i64>,
pub system_ram_bytes: Option<u64>,
pub machine_name: Option<String>,
}Expand description
Next id: 18
Fields
utsname: Option<Utsname>android_build_fingerprint: Option<String>android_device_manufacturer: Option<String>The manufacturer of the product/hardware. Source : “ro.product.manufacturer” Introduced after Android W in Nov 2024 and is not supported on older versions.
android_soc_model: Option<String>The SoC model from which trace is collected
android_guest_soc_model: Option<String>The guest SoC model from which trace is collected in case of VMs
android_hardware_revision: Option<String>The hardware reversion from android device
android_storage_model: Option<String>The storage component from android_device. This field has been introduced after Android W in Aug 2024 and is not supported on older versions.
android_ram_model: Option<String>The RAM component information from android device. This field has been introduced after Android W in Aug 2024 and is not supported on older versions.
android_serial_console: Option<String>The serial console information from android device.
tracing_service_version: Option<String>The version of traced (the same returned by traced --version).
This is a human readable string with and its format varies depending on
the build system and the repo (standalone vs AOSP).
This is intended for human debugging only.
android_sdk_version: Option<u64>The Android SDK vesion (e.g. 21 for L, 31 for S etc). Introduced in Android T.
page_size: Option<u32>Kernel page size - sysconf(_SC_PAGESIZE).
num_cpus: Option<u32>Number of cpus - sysconf(_SC_NPROCESSORS_CONF). Might be different to the number of online cpus. Introduced in perfetto v44.
timezone_off_mins: Option<i32>The timezone offset from UTC, as per strftime(“%z”), in minutes. Introduced in v38 / Android V.
hz: Option<i64>Ticks per second - sysconf(_SC_CLK_TCK). Not serialised as of perfetto v44.
system_ram_bytes: Option<u64>The size of the system RAM in bytes.
On Linux/Android: sysinfo.totalram * sysinfo.mem_unit. Other POSIX (e.g. Mac): sysconf(_SC_PHYS_PAGES) * sysconf(_SC_PAGESIZE).
Introduced in perfetto v54 / Android 26Q1+.
machine_name: Option<String>Human-readable name of the machine this SystemInfo describes, used as the
machine’s label in the UI (falling back to “machine
A producer attributing its data to a non-host machine can set this by emitting a SystemInfo packet to give that machine a name. Only meaningful when the packet carries a non-zero machine_id.
Implementations
Sourceimpl SystemInfo
impl SystemInfo
Sourcepub fn android_build_fingerprint(&self) -> &str
pub fn android_build_fingerprint(&self) -> &str
Returns the value of android_build_fingerprint, or the default value if android_build_fingerprint is unset.
Sourcepub fn tracing_service_version(&self) -> &str
pub fn tracing_service_version(&self) -> &str
Returns the value of tracing_service_version, or the default value if tracing_service_version is unset.
Sourcepub fn android_sdk_version(&self) -> u64
pub fn android_sdk_version(&self) -> u64
Returns the value of android_sdk_version, or the default value if android_sdk_version is unset.
Sourcepub fn page_size(&self) -> u32
pub fn page_size(&self) -> u32
Returns the value of page_size, or the default value if page_size is unset.
Sourcepub fn timezone_off_mins(&self) -> i32
pub fn timezone_off_mins(&self) -> i32
Returns the value of timezone_off_mins, or the default value if timezone_off_mins is unset.
Sourcepub fn num_cpus(&self) -> u32
pub fn num_cpus(&self) -> u32
Returns the value of num_cpus, or the default value if num_cpus is unset.
Sourcepub fn android_soc_model(&self) -> &str
pub fn android_soc_model(&self) -> &str
Returns the value of android_soc_model, or the default value if android_soc_model is unset.
Sourcepub fn android_hardware_revision(&self) -> &str
pub fn android_hardware_revision(&self) -> &str
Returns the value of android_hardware_revision, or the default value if android_hardware_revision is unset.
Sourcepub fn android_storage_model(&self) -> &str
pub fn android_storage_model(&self) -> &str
Returns the value of android_storage_model, or the default value if android_storage_model is unset.
Sourcepub fn android_ram_model(&self) -> &str
pub fn android_ram_model(&self) -> &str
Returns the value of android_ram_model, or the default value if android_ram_model is unset.
Sourcepub fn android_guest_soc_model(&self) -> &str
pub fn android_guest_soc_model(&self) -> &str
Returns the value of android_guest_soc_model, or the default value if android_guest_soc_model is unset.
Sourcepub fn android_device_manufacturer(&self) -> &str
pub fn android_device_manufacturer(&self) -> &str
Returns the value of android_device_manufacturer, or the default value if android_device_manufacturer is unset.
Sourcepub fn android_serial_console(&self) -> &str
pub fn android_serial_console(&self) -> &str
Returns the value of android_serial_console, or the default value if android_serial_console is unset.
Sourcepub fn system_ram_bytes(&self) -> u64
pub fn system_ram_bytes(&self) -> u64
Returns the value of system_ram_bytes, or the default value if system_ram_bytes is unset.
Sourcepub fn machine_name(&self) -> &str
pub fn machine_name(&self) -> &str
Returns the value of machine_name, or the default value if machine_name is unset.