pub struct UiState {
pub timeline_start_ts: Option<i64>,
pub timeline_end_ts: Option<i64>,
pub highlight_process: Option<HighlightProcess>,
}Expand description
Common state for UIs visualizing Perfetto traces. This message can be appended as a TracePacket by UIs to save the visible state (e.g. scroll position/zoom state) for future opening of the trace. Design doc: go/trace-ui-state.
Fields
timeline_start_ts: Option<i64>The start and end bounds of the viewport of the UI in nanoseconds.
This is the absolute time associated to slices and other events in trace processor tables (i.e. the |ts| column of most tables)
timeline_end_ts: Option<i64>highlight_process: Option<HighlightProcess>Implementations
Sourceimpl UiState
impl UiState
Sourcepub fn timeline_start_ts(&self) -> i64
pub fn timeline_start_ts(&self) -> i64
Returns the value of timeline_start_ts, or the default value if timeline_start_ts is unset.
Sourcepub fn timeline_end_ts(&self) -> i64
pub fn timeline_end_ts(&self) -> i64
Returns the value of timeline_end_ts, or the default value if timeline_end_ts is unset.