#[repr(i32)]pub enum ThreadOrdering {
Unspecified = 0,
Explicit = 1,
}Expand description
Specifies how the UI should display thread tracks within a process group relative to each other. Note that this value is simply a hint to the UI and is only valid on the root track descriptor (uuid = 0).
Variants
Unspecified = 0
The default ordering, with no bearing on how the UI will visualise the threads.
Explicit = 1
Order threads by sibling_order_rank of their thread track descriptors.
Threads with lower ranks will be shown before threads with higher ranks.
Threads with no rank specified will be treated as having a rank of 0.
Implementations
Sourceimpl ThreadOrdering
impl ThreadOrdering
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.